@@ -1,6 +1,6 @@
 # adderror.pl
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,19 +19,16 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: adderror.pl,v 2.4 1999/01/11 09:08:26 roman Exp $
+# $Id: adderror.pl,v 2.1 1997/10/02 15:25:40 chris Exp $
 #
 #	$RCSfile: adderror.pl,v $
-#	$Revision: 2.4 $
-#	$Author: roman $
-#	$Date: 1999/01/11 09:08:26 $
+#	$Revision: 2.1 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:25:40 $
 
-require "dpr.pl";
 
 sub adderror {
     local(*object, $msg) = @_;
-
-    return unless defined($msg);
     
     local($*)=1;
     $msg=~ s/^\n+//;
@@ -45,8 +42,6 @@ sub adderror {
 sub addwarning {
     local(*object, $msg) = @_;
     
-    return unless defined($msg);
-    
     local($*)=1;
     $msg=~ s/^\n+//;
     $msg=~ s/\n+$//;
@@ -60,8 +55,7 @@ sub addwarning {
 sub haserror {
     local(*object)=@_;
 
-#    &dpr("defined: ", defined($object{"ue"}), 
-#	 " ue: ", $object{"ue"}, "\n");
+    print STDERR "haserror: defined: ", defined($object{"ue"}), " ue: ", $object{"ue"}, "\n" if ($opt_V);
 
     return defined($object{"ue"});
 }
