@@ -1,6 +1,6 @@
 # cldb.pl
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,28 +19,26 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: cldb.pl,v 2.4 1998/12/09 14:39:08 roman Exp $
+# $Id: cldb.pl,v 2.2 1997/10/02 15:25:42 chris Exp $
 #
 #	$RCSfile: cldb.pl,v $
-#	$Revision: 2.4 $
-#	$Author: roman $
-#	$Date: 1998/12/09 14:39:08 $
+#	$Revision: 2.2 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:25:42 $
 
+#
 # This module contains all routines for classless indexing and lookups
 #
 # it is completely rewritten, much faster and you can now
 # have more databases open at the same time (although the rest of the
 # code doesn't support this yet
 
-# %mspnxl :
-#     keys   -> prefixes in form integer/len
-#     values -> comma separated list of unique keys
-
 require "defines.pl";
 require "misc.pl";
 require "net2net.pl";
 require "addkey.pl";
 
+#
 # cla2unikey(*mspnxl, @clas)
 #
 # gives back an array of unique keys into the database that match these clas
@@ -48,46 +46,26 @@ require "addkey.pl";
 sub cla2unikey {
     local(*mspnxl, @clas)=@_;
 
+    # print STDERR "cla2unikey($cla) called\n";
+
     local(@result)=();
     
     foreach (@clas) {
-       push(@result, 
-	    grep( /$UNIQUEKEYBINDING/o, split("\,", &getvalues(*mspnxl, $_))));
+       # print STDERR "cla2unikey($cla) called $_\n";
+       push(@result, grep( /$UNIQUEKEYBINDING/o, split("\,", &getvalues(*mspnxl, $_))));
     }
+       
     return @result;
+
 }
 
 
-
-################################################################
-##  sub {@tbs@} 
-################################################################
-##
-##  FUNCTIONAL DESCRIPTION:
-##      Find the list of less specifics for prefix $cla. If the 
-##      recursion flag is set, all less specifics (lsps) are 
-##      returned, otherwise only the first less specific.
-##  FORMAL PARAMETERS:
-##      *mspnxl: in
-##          classless index hash
-##      $cla: in
-##          prefix/len
-##      $recurse: in
-##          boolean flag
-##          0 - only one level less specific (that is itself)
-##          1 - all less specifics
-##  RETURN VALUE:
-##      just $cla if not recurse and $cla exists in %mspnxl
-##      when $cla doesn't exist in %mspnxl then first existing
-##      less specific prefix returned.
-##      recurse -> list of less specific prefixes existing in %mslnxl
-##      ordered according to descending prefix lengths 
-##  SIDE EFFECTS:
-##      {@description or none@}
-##  DESIGN:
-##      {@description or none@}
-##   
-################################################################
+#
+# findlsps(*mspnxl, $cla, $recursive)
+#
+# Find the list of less specifics for prefix $cla. If the recursion
+# flag is set, all less specifics (lsps) are returned, otherwise only
+# the first less specific.
 
 sub findlsps {
     local(*mspnxl, $cla, $recurse)=@_;
