@@ -1,6 +1,6 @@
 #       dbmatch - looks up the offsets in the dbm file
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: dbmatch.pl,v 2.6 1999/06/03 12:10:32 rowandb Exp $
+# $Id: dbmatch.pl,v 2.2 1997/10/02 15:25:45 chris Exp $
 #
 #	$RCSfile: dbmatch.pl,v $
-#	$Revision: 2.6 $
-#	$Author: rowandb $
-#	$Date: 1999/06/03 12:10:32 $
+#	$Revision: 2.2 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:25:45 $
 #
 #	looks up the offsets in the dbm file for all keys
 #       and will return an array with the intersection of all
@@ -36,12 +36,11 @@
 
 require "defines.pl";
 require "enukey.pl";
-require "dpr.pl";
 
 sub dbmatch {
     local(*db, *allkeys, $types, $options) = @_;
 
-    &dpr("\@allkeys = (", join(" ", @allkeys), ") \$types = $types\n");
+    # print STDERR "db contents: ", $db{"bl2-test"}, "\n";
 
     local(%tmp)=();
     local(%nonsplitkeys)=();
@@ -67,11 +66,10 @@ sub dbmatch {
        }
           
     }
-#    &dpr("\@classlesstype = (", join(" ", @classlesstypes), ")\n");
-
+    
     foreach $key (@keys) {
-
-#	&dpr("\$key = $key, \$db{\$key} = $db{$key}, \$options = $options\n");
+       
+       print STDERR "dbmatch - key: -$key- value: $db{$key} options: $options\n" if ($opt_V);
         
        if ($key=~ /^$VALIDPREFIXKEY$/o) {
           
@@ -80,8 +78,9 @@ sub dbmatch {
           if (@classlesstypes) {
              %alldbs=();
              @alldbs{@classlesstypes}=(1) x scalar(@classlesstypes);
-#             &dpr("\%alldbs keys: (", join(" ", keys %alldbs), ")",
-#		  "\%alldbs vals: (", join(" ", values %alldbs), ")\n");
+             
+             # print STDERR keys %alldbs, values %alldbs, "\n";
+             
           }
           
           #
@@ -102,10 +101,12 @@ sub dbmatch {
                 @classlesskeys=&findlsps(*mspnxl, $key, ($options & $ALLLESSSPECIFICOPTION));
                 
              }
-#             &dpr("\@classlesskeys = (", join(" ", @classlesskeys), ")\n");
+             
              @newkeys=grep(++$entry{$_}==1, &cla2unikey(*mspnxl, @classlesskeys));
-#             &dpr("\@newkeys = (", join(" ", @newkeys), ")\n");
-
+             
+             # print STDERR "newkeys: ", join(" ", @newkeys), "\n";
+             
+             #
              # this is to get non-split databases have the same behavior
              # as split databases
           
@@ -269,13 +270,13 @@ sub dbmatch {
           @newkeys=($key);
        }
 
-#	&dpr("\@newkeys = (", join(" ", @newkeys), ")\n"); 
+       #print STDERR "new: ", @newkeys, "\n";
        	
        foreach (@newkeys) {
 	
 	  @offsets=split("\,", &getvalues(*db, $_));
-
-#	  &dpr("\@offsets = (", join(" ", @offsets), ")\n"); 
+	  
+	  # print STDERR "offsets: ", @offsets, "\n";
 	  
 	  return () if ((!$classless) && ($options & $EXACTMATCHOPTION) && (!@offsets));
           
@@ -285,24 +286,22 @@ sub dbmatch {
 	      ($options & $INTERSECTIONOPTION) &&
 	      (!((scalar(@newkeys)>1) && (@classlesstypes))) &&
 	      (!($options & ($ALLMORESPECIFICOPTION | $ALLLESSSPECIFICOPTION)))) {
-#	      &dpr("doing intersection\n");
+	     
 	     if (@result) {
-#		 &dpr("before intersection, \@result = (", join(" ", @result), ")\n");
 	     	%tmp=();
 		grep($tmp{$_}++, @offsets);
 		@result=grep($tmp{$_}, @result);
-#		 &dpr("after intersection, \@result = (", join(" ", @result), ")\n");
+		
 	     }
 	     else {
 		@result=@offsets;
-#		&dpr("intersection, \@result = (", join(" ", @result), ")\n");
 	     }
 	     
 	     return () if (!@result);
 	  
 	  }
 	  else {
-#	      &dpr("doing union\n");
+	  
 	     push(@result, grep(!$tmp{$_}++, @offsets));
 	      
 	  }
@@ -310,7 +309,7 @@ sub dbmatch {
        }
        
     }
-    &dpr("\@result = (", join(" ", @result), ")\n");
+    
     return @result;
     
 }
