@@ -1,6 +1,6 @@
 # dbupdate.pl
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: dbupdate.pl,v 2.9 1999/01/12 09:57:05 roman Exp $
+# $Id: dbupdate.pl,v 2.5 1997/10/17 11:08:28 chris Exp $
 #
 #	$RCSfile: dbupdate.pl,v $
-#	$Revision: 2.9 $
-#	$Author: roman $
-#	$Date: 1999/01/12 09:57:05 $
+#	$Revision: 2.5 $
+#	$Author: chris $
+#	$Date: 1997/10/17 11:08:28 $
 
 #
 # This is a client that will update objects read from a file directly
@@ -34,11 +34,14 @@
 # and that it has a database associated to it ...
 
 
-require "getopts.pl";
-require "rconf.pl";
-require "processdata.pl";
-require "dpr.pl";
+@INC = ("LIBDIR", @INC);
 
+require "getopts.pl";
+
+require "rconf.pl";
+
+require "misc.pl";
+require "processdata.pl";
 
 # Parse options:
 #
@@ -53,9 +56,8 @@ require "dpr.pl";
 # -T                    - TEST database update, accept creation of maintainers
 #                         always, but give a warning that this is not the
 #                         case in the normal database
-# -b                    - print debug messages (activated with &dpr call)
 
-&Getopts('Am:MTvVb');
+&Getopts('Am:MTvV');
 
 #
 # Need this below for running perl in tainted mode.
@@ -69,26 +71,22 @@ $ENV{"IFS"} = "";
 
 $conffile=$ENV{"RIPEDBCNF"};
 $conffile= $RIPEConfig{DEFCONFIG} unless $conffile;
-#&dpr("reading config\n");
+print STDERR "dbupdate - reading config\n" if $opt_V;
 &rconf($conffile);
 
 #
 # run on low priority, whois server queries have an
 # higher priority
 
-&lower_priority();
+lower_priority;
 
 if ($opt_m) {
    $opt_M=1;
    $FROM=$opt_m;
    $REPLYTO=$FROM;
-#   &dpr("Treating as mail from $FROM\n");
+   print STDERR "Treating as mail from $FROM\n" if ($opt_V);
 }
 
 &dbupdate("", STDOUT);
 
-exit(0);
-
-
 # end of program
-
