@@ -1,6 +1,6 @@
 # defines.pl
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: defines.pl,v 2.9 1999/02/02 14:42:01 marek Exp $
+# $Id: defines.pl,v 2.2 1997/10/02 15:25:48 chris Exp $
 #
 #	$RCSfile: defines.pl,v $
-#	$Revision: 2.9 $
-#	$Author: marek $
-#	$Date: 1999/02/02 14:42:01 $
+#	$Revision: 2.2 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:25:48 $
 
 $OK		=	1;
 $NOK		=	0;
@@ -53,22 +53,18 @@ $E_NOAUTOUPDATE  =     12;
 $E_NOTNEW        =     13;
 $E_STILLREFERENCED =   14;
 
-# Error messages.
-#
-# Attention: the contents of these strings will be eval'd,
-# 	hence nested quotes
-$MESSAGE[$E_EXIST]	= '"entry already exists"';
-$MESSAGE[$E_NOT_FOUND]	= '"entry not found"';
-$MESSAGE[$E_MULT_MATCH]	= '"more than one match"';
-$MESSAGE[$E_MISMATCH]	= '"mismatch between update and original"';
-$MESSAGE[$E_NOOP]	= '"update results in NOOP"';
-$MESSAGE[$E_OLDER]	= '"update is older than original"';
-$MESSAGE[$E_AUTHFAIL]   = '"authorisation failed, request forwarded to maintainer"';
-$MESSAGE[$E_HIER_AUTHFAIL] = '"hierarchical authorisation failed, request forwarded to maintainer\nof object directly above the to be updated object in the hierarchy"';
-$MESSAGE[$E_NOAUTOUPDATE] = '"the object in the database does not contain\na mandatory ".$ATTL{"mb"}." attribute,\ntherefore user updates of this object are disabled\nplease contact \<$HUMAILBOX\> for updating this object"';
-$MESSAGE[$E_GENERAL]    = '""';
-$MESSAGE[$E_NOTNEW]     = '"object already exists"';
-$MESSAGE[$E_STILLREFERENCED] = '"cannot delete object that is still referenced\nby other objects in the database"';
+$MESSAGE[$E_EXIST]	= "entry already exists";
+$MESSAGE[$E_NOT_FOUND]	= "entry not found";
+$MESSAGE[$E_MULT_MATCH]	= "more than one match";
+$MESSAGE[$E_MISMATCH]	= "mismatch between update and original";
+$MESSAGE[$E_NOOP]	= "update results in NOOP";
+$MESSAGE[$E_OLDER]	= "update is older than original";
+$MESSAGE[$E_AUTHFAIL]   = "authorisation failed, request forwarded to maintainer";
+$MESSAGE[$E_HIER_AUTHFAIL] = "hierarchical authorisation failed, request forwarded to maintainer\nof object direct above the to be updated object in the hierarchy";
+$MESSAGE[$E_NOAUTOUPDATE] = "object cannot be updated\/deleted automatically\nthe to be updated\/deleted object doesn\'t contain\na ".$ATTL{"mb"}." line.\nplease contact \<$HUMAILBOX\> for updating this object";
+$MESSAGE[$E_GENERAL]    = "";
+$MESSAGE[$E_NOTNEW]     = "object already exists";
+$MESSAGE[$E_STILLREFERENCED] = "cannot delete object that is still referenced\nby other objects in one of the databases";
 
 #
 # Return codes for syntax checking the objects
@@ -90,9 +86,9 @@ $O_NOTFOUND=28;
 $O_COULDNOTOPEN=29; 
 
 
-$MESSAGE[$O_OK]		=	'"object OK"';
-$MESSAGE[$O_ERROR]	=	'"object has errors"';
-$MESSAGE[$O_WARNING]	=	'"object has warnings"';
+$MESSAGE[$O_OK]		=	"object OK";
+$MESSAGE[$O_ERROR]	=	"object has errors";
+$MESSAGE[$O_WARNING]	=	"object has warnings";
 
 # Return codes for authorisation
 
@@ -150,7 +146,6 @@ $NOOPOPTION=64;
 $FAILEDOPTION=128;
 $BACKWARDCOMPATIBILITYOPTION=256;
 $ASSIGNEDNICOPTION=512;
-$OVERRIDEINTEGRITY=1024;
 
 #
 # donetdbm (binary) options
@@ -169,7 +164,6 @@ $NONRECURSIVEOPTION=16;
 $FASTOPTION=32;
 $NOSYNTACTICSUGAR=64;
 $EXACTMATCHOPTION=128;
-$NONREFERRALOPTION=256;
 
 #
 # The version of the inputformat we default to
@@ -226,11 +220,7 @@ $VALIDATTRCHAR='\w\-\*';
 #
 # valid domain name regular expression
 
-# $DOMAINNAME='[a-zA-Z\d]+([\.\-][a-zA-Z\d]+)*'; 
-
-# Quick fix to allow "--" in domain names.
-
-$DOMAINNAME='[a-zA-Z\d]+([\.\-]\-*[a-zA-Z\d]+)*'; 
+$DOMAINNAME='[a-zA-Z\d]+([\.\-][a-zA-Z\d]+)*'; 
 
 #
 # valid source attribute regular expression
