@@ -1,6 +1,6 @@
 # donetdbm.pl
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: donetdbm.pl,v 2.5 1998/07/15 18:01:27 joao Exp $
+# $Id: donetdbm.pl,v 2.3 1997/10/02 15:25:49 chris Exp $
 #
 #	$RCSfile: donetdbm.pl,v $
-#	$Revision: 2.5 $
-#	$Author: joao $
-#	$Date: 1998/07/15 18:01:27 $
+#	$Revision: 2.3 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:25:49 $
 
 require "defines.pl";
 require "dbopen.pl";
@@ -137,7 +137,7 @@ sub flushkeys {
          
          if (open(OVERFLOWADD, ">>".$dbfile.shift(@toobig))) {
          
-            &fatalerror("in donetdbm flushkeys: cannot write $dbfile.$_ value: ".shift(@toobig)." code: $!") if ( ! print OVERFLOWADD "\,", shift(@toobig) );
+            print OVERFLOWADD "\,", shift(@toobig);
             close(OVERFLOWADD);
                              
          }
@@ -167,7 +167,7 @@ sub flushkeys {
          
          if (open(OVERFLOWNEW, ">".$dbfile.$_)) {
          
-            &fatalerror("in donetdbm flushkeys: cannot write $dbfile.$_ value: ".shift(@toobignewvalues)." code: $!") if ( ! print OVERFLOWNEW shift(@toobignewvalues) );
+            print OVERFLOWNEW shift(@toobignewvalues);
             close(OVERFLOWNEW);
               
          }
@@ -205,7 +205,7 @@ sub flushclkeys {
    
    open(FLUSHCLKEYS, ">>".$file);
       
-   &fatalerror("in donetdbm flushclkeys: cannot write $file . code: $!") if ( ! print FLUSHCLKEYS $list[$i] );
+   print FLUSHCLKEYS $list[$i];
       
    close(FLUSHCLKEYS);
    
