@@ -1,7 +1,7 @@
 #       encmp - compare two associative arrays
 #               'syntax sugar' is removed before comparing!
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -20,61 +20,46 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: encmp.pl,v 2.8 1999/06/03 12:10:32 rowandb Exp $
+# $Id: encmp.pl,v 2.2 1997/10/02 15:25:49 chris Exp $
 #
 #	$RCSfile: encmp.pl,v $
-#	$Revision: 2.8 $
-#	$Author: rowandb $
-#	$Date: 1999/06/03 12:10:32 $
+#	$Revision: 2.2 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:25:49 $
 #
 #	This routine takes two objects and compares them case insensitive
 #	Returns 1 if objects are equal, else returns 0;
 #
 #       Arguments:
 #	*this, *that		two pointers to assoc arrays
-#       @what                   list of attributes to exclude from comparison
-
 
 sub encmp {
 
-    local(*this, *that, $what, $ignorewhitespace)=@_;
+    local(*this, *that)=@_;
     
     local($a,$b);
-    local(@syntacticsugar)=();
-    local($atype)=&entype(%this);
 
-    my @what = split(/ /, $what);
+    local($atype)=&entype(*this);
 
+    #
     # check if types are different
+    
+    return 0 if ($atype ne &entype(*that));
 
-#    &dpr("First object =", join("*", %this), "\n");
-#    &dpr("Second object =", join("*", %that), "\n");
-    &dpr("\@what=", join(" ", @what), "\n");
-    &dpr("Ignoring whitespace...\n") if ($ignorewhitespace);
-
-    return 0 if ($atype ne &entype(%that));
-
+    #
     # check every attribute line by line...
+    #
     # but do the difficult cases last.
-
-    my(@compareattrs) = split(/\s+/, $OBJATSQ{$atype});
-    my(%excludeattrs) = undef;
-    grep($excludeattrs{$_}++, @what); 
-
-    foreach (@compareattrs) {
+    
+    local(@syntacticsugar)=();
+    
+    foreach (split(/\s+/, $OBJATSQ{$atype})) {
         
         $a=$this{$_};
 	$b=$that{$_};
         
-	next if ($excludeattrs{$_});
-
-	&dpr("Comparing $_: *$a* *$b*\n");
-
-	if ($ignorewhitespace) {
-	    $a =~ s/\s+/ /g;
-	    $b =~ s/\s+/ /g;
-	}        
-
+        # print STDERR "-$a-$b-";
+        
 	# we need to do quite a bit of work for comparing attributes
 	# that might have syntactic sugar so let's store these attributes 
 	# and process them last!
