@@ -1,6 +1,6 @@
 #       enkeys - extract keys from entry
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: enkeys.pl,v 2.4 1999/01/11 09:08:33 roman Exp $
+# $Id: enkeys.pl,v 2.1 1997/10/02 15:25:50 chris Exp $
 #
 #	$RCSfile: enkeys.pl,v $
-#	$Revision: 2.4 $
-#	$Author: roman $
-#	$Date: 1999/01/11 09:08:33 $
+#	$Revision: 2.1 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:25:50 $
 #
 
 #
@@ -69,7 +69,6 @@
 
 require "defines.pl";
 require "net2net.pl";
-require "dpr.pl";
 
 #
 # makekeys
@@ -85,16 +84,16 @@ require "dpr.pl";
 #   only find pointsto keys as specified
 
 sub makekeys {
-
     local($searchstring, $tags, *others)=@_;
-    &dpr("\$searchstring = $searchstring, \$tags = $tags, ",
-	 "\@others = ", join(" ", @others), "\n");
-
+    
+    #
     # we make a dummy object for finding the keys
        
     local(%dummyentry)=();
+    
     local(%OLDKEYS)=();
     local(@tmpkeytags)=($tags);
+    
     local(@keys,@other,@pointsto,@otherpointsto,@classless, @tmpkeytags);
     local($OLDKEYS,$OLDPOINTSTO,$classless);
     
@@ -108,9 +107,11 @@ sub makekeys {
        @KEYS{@tmpkeytags}=0;
        
        $classless=0;
+       
     }
     else {
        
+       #
        # white space, but no real spaces...
        
        $tags="\t";
@@ -124,19 +125,13 @@ sub makekeys {
        $KEYS{$tags}=1;
        
        $classless=1;
+       
     }
 
-#    &dpr("calling enkeys - args:\n\t", )
-
     &enkeys(*dummyentry, $tags, *keys, *others, *pointsto, *otherpointsto, *classless, $classless);
     
-    &dpr("enkeys returned:\n");
-    &dpr("\t\@keys = (", join("*", @keys), ")\n") if (@keys);
-    &dpr("\t\@others = (", join("*", @others), ")\n") if (@others);
-    &dpr("\t\@pointsto = (", join("*", @pointsto), ")\n") if (@pointsto);
-    &dpr("\t\@otherpointsto = (", join("*", @otherpointsto), ")\n") if (@otherpointsto);
-    &dpr("\t\@classless = (", join("*", @classless), ")\n") if (@classless);
-   
+    # print STDERR "-", @keys, "-";
+    
     if ($tags!~ /^\s*$/) {
        
        @KEYS{@tmpkeytags}=@OLDKEYS{@tmpkeytags};
@@ -217,8 +212,6 @@ sub enkeys {
        #
        # only lower case keys, no confusion between _ & -
        $value=~ tr/A-Z_/a-z-/;
-
-#       &dpr("\$tag = $tag, \$value = $value\n");
        
        $*=0;
        
@@ -227,13 +220,14 @@ sub enkeys {
        foreach $value (split(/\n+/, $value)) {
 	  
 	  next if ($value=~ /^ *$/);
-
-#	  &dpr("\$value = $value, \$classless = $classless\n");
+	
+          # print STDERR "enkeys - $classless line: -$value-\n";
 	   
           if (($classless) && ($value=~ /(^| )[\d\:]/)) {
 	     
 	     # print STDERR "enkeys - line: -$value-\n";
-
+	     
+	     #
 	     # this one is not needed but really speeds up the indexing
 	     # normalizerange can handle it but is much slower...
 	        
@@ -275,13 +269,13 @@ sub enkeys {
              $value=~ s/ +\S+$// if ($tag eq "if");
              
              ($newvalue, $code)=&normalizerange($value, $tag);
-#	     &dpr("after normalizerange: \$value = $value, ",
-#		  "\$tag = $tag, \$newvalue = $newvalue, \$code = $code\n");
+	   
+             # print STDERR "enkeys - possible inetnum: $newvalue (was: $value, code: $code)\n";
 	      
              if ($code==$O_OK) {
                 
                 @classless{&range2prefixes($newvalue)}=();
-#                &dpr("\@classless = (", join(" ", @classless), "\n");
+                
                 next;
                 
 	     }
@@ -289,16 +283,15 @@ sub enkeys {
           }	   
 	  
 	  @values=grep(length($_)>$SMALLESTKEY, split(/ /, $value));
-
-#	  &dpr("\@values = (", join(" ", @values), ")\n");
-
+	  
           if ($POINTSTO{$tag}) {
 	     
 	     $tagconnect=$tag."\t";
 	     
+	     #
 	     # next one is a special for as macros and as'es
 	      
-             if (grep($_ !~ /^a[nm]$/, split(/ /, $POINTSTO{$tag}))) {
+             if (grep($_!~ /^a[nm]$/, split(/ /, $POINTSTO{$tag}))) {
                 
                 @pointsto{grep($_=$tagconnect.$_, @values)}=() if (@values);
                 $otherpointsto{$tagconnect.$value}=undef if (($value=~ / /) && ($POINTSTO{$tag}=~ /(^| )(pn|ro)( |$)/));
