@@ -1,6 +1,6 @@
 #       enparse - read RIPE database and check syntax errors
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: enparse.pl,v 2.6 1999/05/17 10:05:48 engin Exp $
+# $Id: enparse.pl,v 2.2 1997/10/02 15:25:51 chris Exp $
 #
 #	$RCSfile: enparse.pl,v $
-#	$Revision: 2.6 $
-#	$Author: engin $
-#	$Date: 1999/05/17 10:05:48 $
+#	$Revision: 2.2 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:25:51 $
 #
 #	ARGUMENTS:	filehandle to read from
 #	RETURNS:	INTEGER object_status
@@ -52,9 +52,6 @@ require "entype.pl";
 require "syntax.pl";
 require "defines.pl";
 require "adderror.pl";
-require "dpr.pl";
-require "pgp.pl";
-require "i6.pl";
 
 sub readsomething {
     local($file)=@_;
@@ -67,8 +64,6 @@ sub readsomething {
     
     local($newtag);
 
-    &dpr("\n");
-
     while (<$file>) {
         
         #
@@ -79,7 +74,7 @@ sub readsomething {
            $PASSWORD=$1;
            $PASSWORD=~ s/\s*$//;
            
-#           &dpr("password found: ", $PASSWORD, "\n");
+           print "password found: ", $PASSWORD, "\n" if ($opt_V);
            
            next;
            
@@ -102,27 +97,22 @@ sub readsomething {
 	   
 	   s/ *$//;
 	   
-#
-# no need for this special case for merging consecutive lines with same
-# tags because lines with same tags are merged to the same $entry{$tag}
-# in any case later on //snabb 980924
-#
-#	   if (($tag eq $newtag) || ($tag eq $ATTL{$newtag}) || ($tag eq $ATTR{$newtag})) {
-#	      
-#	      if (s/ *\\$//) {
-#	         @continuedlines=($_);
-#	      }
-#	      elsif ($_) {
-#	      
-#	         push(@lines, $_);
-#	      
-#	      }
-#	      else {
-#	         push(@lines,"") if ($lines[$#lines]);
-#	      }
-#	       
-#	   }
-#	   else {
+	   if (($tag eq $newtag) || ($tag eq $ATTL{$newtag}) || ($tag eq $ATTR{$newtag})) {
+	      
+	      if (s/ *\\$//) {
+	         @continuedlines=($_);
+	      }
+	      elsif ($_) {
+	      
+	         push(@lines, $_);
+	      
+	      }
+	      else {
+	         push(@lines,"") if ($lines[$#lines]);
+	      }
+	       
+	   }
+	   else {
 	      
               if ($entry{$tag}) {
                  $entry{$tag}=join("\n",$entry{$tag},@lines) if (scalar(@lines));
@@ -130,11 +120,6 @@ sub readsomething {
               else {
                  $entry{$tag}=join("\n",@lines) if (scalar(@lines));
               }
-
-	      # @lines are now saved in $entry, so lets clear it up to prevent
-	      # joining them with @continuedlines (bug ID 1998-38)
-	      # //snabb 980924
-	      @lines = ();
                
               $tag=$ATTR{$newtag};
                 
@@ -154,7 +139,7 @@ sub readsomething {
 	         @lines=("");
 	      }
                 
-#	   }
+	   }
 	       
            $inentry=$O_OK;
            
@@ -250,7 +235,7 @@ sub checkobject	{
     local(%usefield) = ();
     local($i);
 
-    &dpr("called with \%object = " . join("*", %object) . "\$type = $type\n");
+    print STDERR "checkobject - called\n" if $opt_V;
     
     foreach $i ((split(/\s+/, $OBJATSQ{$type}),"ud","uo","uw","ue")) {
 	$knownfield{$i}=1;
@@ -268,8 +253,6 @@ sub checkobject	{
 	$usefield{$i} = 1;
     }
 
-# Warn about obsoleted atttibutes and skip them
-
     foreach (split(/\s+/, $OBS{$type})) {
 	if ($object{$_}) {
 	    &addwarning(*object,
@@ -281,8 +264,6 @@ sub checkobject	{
 	}
     }
 
-#Go through all the attributes in this object
-
     foreach $i (keys %usefield) {
 	
 	if (!$knownfield{$i}) {
@@ -295,7 +276,6 @@ sub checkobject	{
 			  "attribute \"$i\" unknown in $ATTL{$type} object");
 	    }
 	    $rtcode = $O_ERROR;
-	    next;
 	}
 
 	undef $mandfield{$i} unless $object{$i} eq "";
@@ -337,8 +317,6 @@ sub checkobject	{
 
     }
 
-# Complain about missing or incomplete mandatory fields
-
     foreach $i (keys %mandfield) {
 	if ($mandfield{$i}) {
 	    if (defined($object{$i}) && ($object{$i} =~ /^\n*$/)) {
@@ -352,7 +330,7 @@ sub checkobject	{
 	}
     }
     
-#    &dpr("returned \$rtcode = $rtcode\n");
+    print STDERR "checkobject - returned\n" if $opt_V;
     
     return $rtcode;
     
@@ -365,15 +343,15 @@ sub enparse {
     local($rtcode);
     local($stat,$type);
 	
-#    &dpr("reading something\n");
+    print STDERR "enparse - reading something\n" if $opt_V;
 
     ($stat, %entry)=&readsomething($file);
 
-    &dpr("\%entry = " . join("*", %entry) . "\n");
+    # print STDERR %entry, "\n";
     
     return $EOF if ($stat==$EOF);
 
-    $type=&entype(%entry);
+    $type=&entype(*entry);
     
     # Now start the syntax checking
     #
@@ -382,33 +360,33 @@ sub enparse {
     
     $rtcode=&requiredsyntaxcheck(*entry, $type);
     
-    # &dpr("\%entry = " . join("*", %entry) . "\n");
-#   &dpr("left requiredsyntaxcheck($rtcode)\n");
+    # print STDERR %entry, "\n";
+    print STDERR "enparse - left requiredsyntaxcheck($rtcode)\n" if ($opt_V);
     
     #
     # do all other checks 
     
     if ((!defined($entry{"ud"})) && ($rtcode!=$O_ERROR)) {
        
-       &dpr("checking object format\n");
+       print STDERR "enparse - checking object format\n" if $opt_V;
        
        local($code)=&checkobject(*entry, $type);
        
        # print STDERR %entry, "\n";
        
-#       &dpr("enparse - left checkobject($code)\n");
+       print STDERR "enparse - left checkobject($code)\n" if ($opt_V);
        
        $rtcode=$code if (($code==$O_ERROR) || (($code==$O_WARNING) && ($rtcode!=$O_ERROR)));
        
        if ($rtcode!=$O_ERROR) {
        
-          &dpr("checking object syntax\n");
+          print STDERR "enparse - checking object syntax\n" if $opt_V;
 	  
 	  $code=&checksyntax(*entry);
 	  
 	  # print STDERR %entry, "\n";
 	  
-#	  &dpr("left checksyntax($code)\n");
+	  print STDERR "enparse - left checksyntax($code)\n" if ($opt_V);
 	  
 	  $rtcode=$code if (($code==$O_ERROR) || (($code==$O_WARNING) && ($rtcode!=$O_ERROR)));
        
@@ -416,26 +394,11 @@ sub enparse {
        
     }
     
-    if ($type eq "kc" && $rtcode != $O_ERROR) {
-       print STDERR "enparse - adding the generated fields in a certificate object \n" if ($opt_V);
-
-       genPGPkc(*entry, $type) == $O_ERROR
-	   and $rtcode = $O_ERROR;
-    }
-
-    if ($type eq "i6" && $rtcode != $O_ERROR) {
-       print STDERR "enparse - adding the generated fields in an inet6num object \n" if ($opt_V);
-
-       geni6st(*entry, $type) == $O_ERROR
-	   and $rtcode = $O_ERROR;
-    }
-
     # print STDERR %entry, "\n";
-    &dpr("Exiting enparse.\nExit code: $rtcode\nType: $type\nEntry:",
-	 %entry,"\n");
     
     return ($rtcode, $type, %entry);
     
+    
 }
 
 1;
