@@ -1,6 +1,6 @@
 #       entype - return type of RIPE database entry
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: entype.pl,v 2.3 1998/12/09 14:39:15 roman Exp $
+# $Id: entype.pl,v 2.1 1997/10/02 15:25:52 chris Exp $
 #
 #	$RCSfile: entype.pl,v $
-#	$Revision: 2.3 $
-#	$Author: roman $
-#	$Date: 1998/12/09 14:39:15 $
+#	$Revision: 2.1 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:25:52 $
 #
 #       This routine returns the type of RIPE database entry given to it.
 #	An entry type is defined by the first line of an entry eg
@@ -35,8 +35,8 @@
 
 sub entype {
 
-    my(%object) = @_;
- 
+    local(*object) = @_;
+  
     foreach (keys %OBJATSQ) {
 	
 	return ($_) if ($object{$_});
