@@ -1,6 +1,6 @@
 #       enwrite - write RIPE database entry
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: enwrite.pl,v 2.5 1998/12/09 14:39:16 roman Exp $
+# $Id: enwrite.pl,v 2.1 1997/10/02 15:25:53 chris Exp $
 #
 #	$RCSfile: enwrite.pl,v $
-#	$Revision: 2.5 $
-#	$Author: roman $
-#	$Date: 1998/12/09 14:39:16 $
+#	$Revision: 2.1 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:25:53 $
 #
 #	This routine writes a RIPE database entry to standard output
 #	in long or short form.
@@ -37,7 +37,6 @@
 #       $withsugar      boolean flag for with or without syntactic sugar
 
 require "entype.pl";
-require "dpr.pl";
 
 sub enwrite {
 
@@ -47,12 +46,7 @@ sub enwrite {
     
     local($val);
     local(@errs)=();
-    local($type)=&entype(%object);
-
-#    &dpr("called with \$output = $output\n");
-#    &dpr("\%object = ". join("*", %object) . "\n");
-#    &dpr("\$long = $long, \$witherrors = $witherrors, \$withsugar = $withsugar\n");
-#    &dpr("\$type = $type\n");
+    local($type)=&entype(*object);
     
     @errs=("uw","ue") if $witherrors;
 
@@ -64,8 +58,7 @@ sub enwrite {
 	return 0 if (!$long);
 	return 0 if (!$witherrors);
 
-        &fatalerror("enwrite(1): cannot write. code: $!") if ( ! print $output "\n");
-
+        print $output "\n";
     
         $offset=tell($output);
 
@@ -74,7 +67,7 @@ sub enwrite {
 	    next if (grep(/^$key$/,@errs));
 	    
 	    foreach $val (split(/\n/, $object{$key})) {
-
+	    
 	       if (($long) && ($ATTL{$key})) {
 	          $key=$ATTL{$key};
 	       }
@@ -82,13 +75,13 @@ sub enwrite {
 	          $key="*".$key;
 	       }
 	       
-               &fatalerror("enwrite(2): cannot write. code: $!") if ( ! printf $output "%-15s %s\n", $key.":", $val );
+	       printf $output "%-15s %s\n", $key.":", $val;
 	       
 	    }
 	
 	}
 	
-        &fatalerror("enwrite(3): cannot write. code: $!") if ( ! printf $output "%-15s %s\n", $ATTL{"ue"}.":", "Unknown object type" );
+	printf $output "%-15s %s\n", $ATTL{"ue"}.":", "Unknown object type";
 	
 	return $offset;
     
@@ -96,7 +89,7 @@ sub enwrite {
 
     if ($object{$type}) {
 
-       &fatalerror("enwrite(4): cannot write. code: $!") if ( ! print $output "\n"); 
+       print $output "\n";
     
        $offset=tell($output);
 	    
@@ -143,11 +136,11 @@ sub enwrite {
 
 		    # END HARDCODED
 
-                    &fatalerror("enwrite(5): cannot write. code: $!") if ( ! printf $output "%-12s %s\n", $ATTL{$key}.":", $val );
-
+		    printf $output "%-12s %s\n", $ATTL{$key}.":", $val;
+		
 		}
 		else {
-                    &fatalerror("enwrite(6): cannot write. code: $!") if ( ! print $output "*", $key, ": ", $val, "\n" );
+		    print $output "*", $key, ": ", $val, "\n";
 		}
 	    }
 	}
