@@ -1,6 +1,6 @@
 # hiermnt.pl
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: hiermnt.pl,v 2.6 1999/05/28 16:19:46 roman Exp $
+# $Id: hiermnt.pl,v 2.1 1997/10/02 15:25:55 chris Exp $
 #
 #	$RCSfile: hiermnt.pl,v $
-#	$Revision: 2.6 $
-#	$Author: roman $
-#	$Date: 1999/05/28 16:19:46 $
+#	$Revision: 2.1 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:25:55 $
 
 # hiermnt.pl - implements the hierarchical authorization methods
 # it works only for creation right now...
@@ -38,7 +38,6 @@
 
 require "notify.pl";
 require "entype.pl";
-require "dpr.pl";
 
 sub HierarchicalAuthorization {
     local(*db,*OldObject,*NewObject,$type, $options)=@_;
@@ -55,20 +54,13 @@ sub HierarchicalAuthorization {
     
        if ($options & $NEWOPTION) {
        
-#          &dpr("hierarchial authorization (create: $type)\n");
+          print STDERR "hiermnt - hierarchial authorization (create: $type)\n" if $opt_V;
        
           if ($type eq "in") {
        
              return &AuthorizeInetnum(*db, $options, $type, *OldObject, *NewObject, $NewObject{$type}, &enukey(*NewObject,$type));
           
           }
-##\begin[1999 02 18]{engin}
-          elsif ($type eq "i6") {
-       
-             return &AuthorizeInetv6num(*db, $options, $type, *OldObject, *NewObject, $NewObject{$type}, &enukey(*NewObject,$type));
-          
-          }
-##\end{engin}
           elsif ($type eq "dn") {
           
              return &AuthorizeDomain(*db, $options, $type, *OldObject, *NewObject, $NewObject{$type});
@@ -97,32 +89,26 @@ sub DoHierarchicalAuthorization {
     local(%directabove);
     local($key);
 
-#    &dpr("keys: ".join(" ",@keys)."\n");
+    print STDERR "DoHierAuth: keys: ".join(" ",@keys)."\n" if ($opt_V);
     
     foreach $key (&dbmatch(*db, *keys, "", 0)) {
        
        &enread($db, *directabove, $key);
         
-#       &dpr("hierarchical offset=$key, object=", $directabove{$type}, "\n");
+       print STDERR "DoHierAuth - hierarchical offset=$key, object=", $directabove{$type}, "\n"  if $opt_V;
  
        # check the type, we might have a non-split database!
  
-       if ($type eq &entype(%directabove)) {
+       if ($type eq &entype(*directabove)) {
        
           $returncode=$O_OK;
             
-#          &dpr("hierarchical last step ml=", $directabove{"ml"}, "...\n");
+          print STDERR "DoHierAuth - hierarchical last step ml=", $directabove{"ml"}, "...\n" if $opt_V;
           
           if ($directabove{"ml"}) {
           
-	      if (&Maintainer(*OldObject, *NewObject, 
-			      $options, $directabove{"ml"})) {
-		  &NotifyMaintainers(*OldObject, *NewObject, $directabove{"ml"});
-	      }
-	      else{
-		  $returncode = $E_HIER_AUTHFAIL;
-	      }
-
+             $returncode=$E_HIER_AUTHFAIL if (!&Maintainer(*OldObject, *NewObject, $options, $directabove{"ml"}));
+          
           }
           
           last;
@@ -151,13 +137,13 @@ sub AuthorizeInetnum {
      
     $directabove{$type}=$value;
     
-#    &dpr("hierarchical inetnum direct above=",$directabove{$type},"\n");
+    print STDERR "hiermnt - hierarchical inetnum direct above=",$directabove{$type},"\n" if $opt_V;
     
     local(@keys,@other,@pointsto,@otherspointsto,@classless);
     
     &enkeys(*directabove, $KEYS{$type}, *keys, *other, *pointsto, *otherspointsto, *classless, 1);
     
-#    &dpr("hierarchical inetnum keys=", join(" ", @classless) ,"\n");
+    print STDERR "hiermnt - hierarchical inetnum keys=", join(" ", @classless) ,"\n"  if $opt_V;
     
     #
     # we don't have time for sophisticated routines now
@@ -180,8 +166,7 @@ sub AuthorizeInetnum {
     
     }
     
-#    &dpr("hierarchical inetnum lessspecifics=", 
-#	 join(" ", @lessspecifics) ,"\n");
+    print STDERR "hiermnt - hierarchical inetnum lessspecifics=", join(" ", @lessspecifics) ,"\n"  if $opt_V;
     
     #
     # remove doubles (grep perl trick, see camel book)
@@ -190,8 +175,7 @@ sub AuthorizeInetnum {
     grep($tmp{$_}++, @lessspecifics);
     @lessspecifics=keys(%tmp);
     
-#    &dpr("hierarchical inetnum after removing doubles lessspecifics=", 
-#	 join(" ", @lessspecifics) ,"\n");
+    print STDERR "hiermnt - hierarchical inetnum after removing doubles lessspecifics=", join(" ", @lessspecifics) ,"\n"  if $opt_V;
     
     #
     # find the smallest objects that are bigger then the current object
@@ -203,7 +187,7 @@ sub AuthorizeInetnum {
     
     $size=&quad2int("255.255.255.255",1);
     
-#    &dpr("start size: $size\n");
+    print STDERR "start size: $size\n" if $opt_V;
     
     foreach $key (@lessspecifics) {
        
@@ -216,7 +200,7 @@ sub AuthorizeInetnum {
        
           ($newtype, %foundobject)=&uniquekey2entry($uniquekey);
           
-#          &dpr("newtype: $newtype name: ",$foundobject{$newtype},"\n");
+          print STDERR "newtype: $newtype name: ",$foundobject{$newtype},"\n" if $opt_V;
        
           #
           # don't use objects with another type, this is for non split databases
@@ -225,7 +209,7 @@ sub AuthorizeInetnum {
           
              ($newrange, $code)=&normalizerange($foundobject{$type}, $type);
           
-#             &dpr("newrange: $newrange code: $code\n");
+             print STDERR "newrange: $newrange code: $code\n" if $opt_V;
              
              ($ip1,$ip2)=split(/ *\- */, $newrange);
        
@@ -238,14 +222,14 @@ sub AuthorizeInetnum {
              
                 if ($newsize==$size) {
                 
-#                   &dpr("same size: $newsize\n");
+                   print STDERR "same size: $newsize\n" if $opt_V;
                 
                    push(@directabove,$key);   
                 
                 }
                 else {   
                 
-#                   &dpr("newsize: $newsize\n");
+                   print STDERR "newsize: $newsize\n" if $opt_V;
                 
                    $size=$newsize;
                    @directabove=($key);
@@ -270,93 +254,6 @@ sub AuthorizeInetnum {
     
 }
     
-##\begin[1999 02 18]{engin}
-sub AuthorizeInetv6num{
-
-    local(*db, $options, $type, *OldObject, *NewObject, $value, $uniquekey)=@_;
-    
-    local($returncode)=$O_OK;
-    local($code);
-    
-    local(%directabove)=();
-    local(@lessspecifics)=();
-     
-    local($key); 
-     
-    $directabove{$type}=$value;
-    
-#    &dpr("hierarchical inetnum direct above=",$directabove{$type},"\n");
-    
-    local(@keys,@other,@pointsto,@otherspointsto,@classless);
-    
-    &enkeys(*directabove, $KEYS{$type}, *keys, *other, *pointsto, *otherspointsto, *classless, 1);
-    
-#    &dpr("hierarchical inetnum keys=", join(" ", @classless) ,"\n");
-    
-    #
-    # we don't have time for sophisticated routines now
-    # and it looks like brute force might be more efficient anyway
-    # so here we go ...
-    #
-    # first find all less specific objects
-    
-    foreach $key (@classless) {
-    
-       #
-       # we try to find all less specifics to be sure that we find
-       # the right objects in case of non-split databases
-       # no time right now to handle this differently for split and
-       # and non split databases...
-       # note: a parent in a non-split database might be an object
-       # with another type, yes we might call this a bug...
-       
-       push(@lessspecifics, &findlsps(*mspnxl, $key, 1));
-
-    
-    }
-    
-#    &dpr("hierarchical inetnum lessspecifics=", 
-#	 join(" ", @lessspecifics) ,"\n");
-    
-    #
-    # remove doubles (grep perl trick, see camel book)
-    
-    local(%tmp)=();
-    grep($tmp{$_}++, @lessspecifics);
-    @lessspecifics=keys(%tmp);
-    
-#    &dpr("hierarchical inetnum after removing doubles lessspecifics=", 
-#	 join(" ", @lessspecifics) ,"\n");
-    
-    #
-    # find the smallest objects that are bigger then the current object
-    
-    local(@directabove)=();
-
-# now, try to find the smallest one in @lessspecifics:
-    local($size);
-    $size = 0;
-    foreach $key  (@lessspecifics){
-       ($prefixv6,$lengthv6) = split(/\//,$key);
-       if ($lengthv6 > $size){
-          $size = $lengthv6;
-          @directabove = ($key); 
-       }
-    }
-
-    
-    
-    $code=&DoHierarchicalAuthorization(*db, $options, $type, *OldObject, *NewObject, *directabove);
-    
-    # everything is fine if we didn't find any parent object
-    
-    return $O_OK if ($code==$O_NOTFOUND);
-    
-    return $code;
-
-}
-##\end{engin}
-
 sub AuthorizeDomain {
     local(*db, $options, $type, $OldObject, $NewObject, $domain)=@_;
     
@@ -369,7 +266,7 @@ sub AuthorizeDomain {
     
     if (($domain!~ /\./) && ($options & $NEWOPTION)) {
        
-       return $E_HIER_AUTHFAIL;
+       $returncode=$E_HIER_AUTHFAIL;
 
     }
     
@@ -381,12 +278,11 @@ sub AuthorizeDomain {
              
        $directabove{$type}=$1;
        
-#       &dpr("hiermnt - hierarchical domain direct above=",
-#	    $directabove{$type},"\n");
+       print STDERR "hiermnt - hierarchical domain direct above=",$directabove{$type},"\n" if $opt_V;
        
        &enkeys(*directabove, $KEYS{$type}, *keys, *other, *pointsto, *otherspointsto, *classless, 0);
        
-#       &dpr("hiermnt - hierarchical domain keys=", join(" ", @keys) ,"\n");
+       print STDERR "hiermnt - hierarchical domain keys=", join(" ", @keys) ,"\n"  if $opt_V;
        
        $code=&DoHierarchicalAuthorization(*db, $options, $type, *OldObject, *NewObject, *keys);
        
@@ -396,7 +292,7 @@ sub AuthorizeDomain {
     
     # we didn't find a parent object
     
-    return $O_OK;
+    return $E_HIER_AUTHFAIL;   
           
 }    
 
