@@ -1,6 +1,6 @@
 #       indexdb - generate a DBM file from an ASCII dbase file
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: indexdb.pl,v 2.7 1999/01/12 09:57:05 roman Exp $
+# $Id: indexdb.pl,v 2.4 1997/10/17 11:08:45 chris Exp $
 #
 #	$RCSfile: indexdb.pl,v $
-#	$Revision: 2.7 $
-#	$Author: roman $
-#	$Date: 1999/01/12 09:57:05 $
+#	$Revision: 2.4 $
+#	$Author: chris $
+#	$Date: 1997/10/17 11:08:45 $
 
 require "getopts.pl";
 
@@ -33,7 +33,7 @@ require "rconf.pl";
 require "misc.pl";
 require "donetdbm.pl";
 
-&Getopts('cs:t:T:Vb');
+&Getopts('cs:t:T:V');
 
 local($conffile) = $ENV{"RIPEDBCNF"};
 $conffile = $RIPEConfig{DEFCONFIG} unless $conffile;
@@ -44,7 +44,7 @@ $conffile = $RIPEConfig{DEFCONFIG} unless $conffile;
 # run on low priority, whois server queries have an
 # higher priority
 
-&lower_priority();
+lower_priority;
 
 local($error)=0;
 local(@splitdbs)=split(/,/, $opt_T) if ($opt_T);
@@ -193,7 +193,7 @@ else {
          # print STDERR $type, keys %entry, $entry{"so"}, $CLASSLESSDBS{$entry{"so"}};
          
          if ($SPLIT{$entry{"so"}}) {
-            push(@classlessoptions, $CLASSLESSDBS{&entype(%entry)});
+            push(@classlessoptions, $CLASSLESSDBS{&entype(*entry)});
          }
          else {
             push(@classlessoptions, $CLASSLESSDBS{$entry{"so"}});
