@@ -1,6 +1,6 @@
 #       internic2ripe - generate RIPE database objects from the InterNIC
 #                       database dump files
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: internic2ripe.pl,v 2.4 1999/01/12 09:57:06 roman Exp $
+# $Id: internic2ripe.pl,v 2.2 1997/10/02 15:25:56 chris Exp $
 #
 #	$RCSfile: internic2ripe.pl,v $
-#	$Revision: 2.4 $
-#	$Author: roman $
-#	$Date: 1999/01/12 09:57:06 $
+#	$Revision: 2.2 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:25:56 $
 
 require "getopts.pl";
 
@@ -34,7 +34,7 @@ require "misc.pl";
 require "net2net.pl";
 
 
-&Getopts('t:b');
+&Getopts('t:');
 
 if ((@ARGV) || (!$opt_t)) {
     
