@@ -1,7 +1,7 @@
 #       internicstats2inetnum - generate inetnum objects from the InterNIC
 #                               statistics files
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -20,13 +20,13 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: internicstats2inetnums.pl,v 2.6 1998/12/09 14:39:18 roman Exp $
+# $Id: internicstats2inetnums.pl,v 2.3 1997/10/02 15:25:56 chris Exp $
 #
 #
 #	$RCSfile: internicstats2inetnums.pl,v $
-#	$Revision: 2.6 $
-#	$Author: roman $
-#	$Date: 1998/12/09 14:39:18 $
+#	$Revision: 2.3 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:25:56 $
 
 
 require "defines.pl";
@@ -43,6 +43,21 @@ $conffile = $RIPEConfig{DEFCONFIG} unless $conffile;
 
 local($value, $code, $day, $month);
 
+local(%month2number)=("jan", "01",
+                      "feb", "02",
+                      "mar", "03",
+                      "apr", "04",
+                      "may", "05",
+                      "jun", "06",
+                      "jul", "07",
+                      "aug", "08",
+                      "sep", "09",
+                      "sept", "09",
+                      "oct", "10",
+                      "nov", "11",
+                      "dec", "12");
+                      
+
 local($remark)="
 *rm: this network is assigned by the InterNIC
 *rm: please query whois.internic.net for more information.
@@ -55,31 +70,30 @@ local($trailer)="
 &printrights(STDOUT);
 
 my($line);
-
 while ($line=<>) {
    
-
-   while ($line =~ /IP-Network:(\d+\.\d+\.\d+\.\d+\/\d+)/) {
+   if ($line =~ /\s(\d+\.\d+\.\d+\.\d+\/\d+)/) {
       
       ($value, $code)=&normalizerange($1, "in");
       
-      push @value,$value if ($code==$O_OK);
+      next if ($code!=$O_OK);
      
       $line=<>;
-   }
-
-   if ($line =~ /Created\:(\d+)/i) {
+      if ($line =~ /date\:\s+(\d+)\-([a-zA-Z]+)\-(\d+)/i) {
          
-#         $day=substr ($1,6,2);
-#         $month=substr($1,4,2);
-#	 $year=substr($1,2,2);
-	$date=substr($1,0,8);
+         $day=$1;
+         $day="0".$day if ($day<10);
+         ($month=$2)=~ tr/A-Z/a-z/;
          
-     foreach (@value) {
-#       print STDOUT "\n*in: ", shift @value, $remark, $year, $month, $day, $trailer;
-       print STDOUT "\n*in: ", shift @value, $remark, $date, $trailer;
-     }
+         print STDOUT "\n*in: ", $value, $remark, $3, $month2number{$month}, $day, $trailer;
 
-   }
+      }
+      else {
+         
+         print STDOUT "\n*in: ", $value, $remark, $trailer;
+         
+      }
       
+   }   
+   
 }
