@@ -1,8 +1,7 @@
-
 # maintainer.pl - implements all functions associated with the maintainer
 # attribute, as defined in ripe-??
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -21,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: maintainer.pl,v 2.12 1999/10/05 14:46:32 marek Exp $
+# $Id: maintainer.pl,v 2.4 1997/10/02 15:25:57 chris Exp $
 #
 #	$RCSfile: maintainer.pl,v $
-#	$Revision: 2.12 $
-#	$Author: marek $
-#	$Date: 1999/10/05 14:46:32 $
+#	$Revision: 2.4 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:25:57 $
 
 # There is a few global variables it will use for authorisation:
 # 
@@ -48,7 +47,6 @@
 require "notify.pl";
 require "entype.pl";
 require "hiermnt.pl";
-require "dpr.pl";
 
 # %CurMaintainer and %ExistMaintainer seem to be local to this file
 # and used by various subs within it.
@@ -59,10 +57,8 @@ sub Maintainer {
     
     local($mntners, $mntner);
     
-#    &dpr("othermntners=$othermntners, newmb: ", 
-#	 $NewObject{"mb"}, ", oldmb: ", $OldObject{"mb"},"\n");
-#    &dpr("override option: ", ($options & $OVERRIDEOPTION), "\n");
-
+    print STDERR "Maintainer - (othermntners=$othermntners, newmb: ", $NewObject{"mb"}, ", oldmb: ", $OldObject{"mb"},")\n" if $opt_V;
+    
     if ($othermntners) {
        $mntners=$othermntners; 
     } 
@@ -82,30 +78,7 @@ sub Maintainer {
 	
     return 1 if (!$mntners);
 
-    # special case - adding maintainers to the TEST database
-    # which are maintained by themselves - skip authorization
-
-    return 1 if ($opt_T)                 
-	     && ($options & $NEWOPTION) 
-	     && ($NewObject{"mt"}) && ($mntners =~ /$NewObject{"mt"}/);
-
-# see comment about notifying maintainers near the end of this function
-
-#    if (($options & $NEWOPTION) && 
-#	($opt_T)               &&
-#	($mntners =~ /$NewObject{"mt"}/)) {
-#
-#	# Notify maintainers
-#	if ($othermntners) {
-#	    &NotifyMaintainers(*OldObject, *NewObject, $othermntners);
-#	}
-#	else {
-#	    &NotifyMaintainers(*OldObject, *NewObject, "");
-#	}	
-#	return 1;
-#    }
-
-
+    #
     # check authorization if no override
 
     if (!($options & $OVERRIDEOPTION)) {
@@ -114,6 +87,8 @@ sub Maintainer {
 
        foreach $mntner (split(/\s+/, $mntners)) {
 
+          print STDERR "maintainer - maintainer: $maintainer\n" if ($opt_V);
+	  
           if ($options & $NEWOPTION) {  
              last if (($status=&VrfyMaint($mntner, *NewObject)));
           }
@@ -123,7 +98,6 @@ sub Maintainer {
 	
        }
     
-
        if (!$status) {
 
           #
@@ -144,28 +118,19 @@ sub Maintainer {
     }
     
     #
-    # Notify maintainers removed out of this function
-    # we don't want to notify maintainers about the success 
-    # while hierarchical authorisation is still to come and could fail
-    # And this is side effect after all
+    # Notify maintainers
 
-#    if ($othermntners) {
-#       &NotifyMaintainers(*OldObject, *NewObject, $othermntners);
-#    }
-#    else {
-#       &NotifyMaintainers(*OldObject, *NewObject, "");
-#    }
+    if ($othermntners) {
+       &NotifyMaintainers(*OldObject, *NewObject, $othermntners);
+    }
+    else {
+       &NotifyMaintainers(*OldObject, *NewObject, "");
+    }
 	
     return 1;
     
 }
 
-# GetMaintainer($maintainername, $source, $lognotexistingmntners)
-#
-# Get maintainer object from database. As a "side effect" sets
-# global variables %ExistMaintainer and %CurMaintainer which are
-# also used outside of this function.
-
 sub GetMaintainer {
     local($maintainername, $source, $lognotexistingmntners) = @_;
     local($mntdb)='mntdb';
@@ -177,7 +142,7 @@ sub GetMaintainer {
 
     local(@keys) = ($normalized);
 
-    return %CurMaintainer if ($CurMaintainer{"mt"} eq $maintainername);
+    return 1 if ($CurMaintainer{"mt"} eq $maintainername);
 
     if ($SPLIT{$source}) {
 	$dbfile = "$DBFILE{$source}.mt";
@@ -191,7 +156,7 @@ sub GetMaintainer {
 		    "maintainer: $maintainername\n");
 	    # Set error, should not happen!!!!!
 	    &dbclose(*mntdb);
-	    return undef;
+	    return 0;
 	}
 	if (!$matches[0]) {
 	    &syslog(
@@ -199,30 +164,31 @@ sub GetMaintainer {
 		    "GetMaintainer() no match found for maintainer $maintainer"
 		    ) if ($lognotexistingmntners);
 	    &dbclose(*mntdb);
-	    return undef;
+	    return 0;
 	}
 	&enread($mntdb, *CurMaintainer, $matches[0]);
 	$ExistMaintainer{$CurMaintainer{"mt"}} = 1;
 	&dbclose(*mntdb);
-	return %CurMaintainer;
+	return 1;
     }
     else {
 	&syslog("ERRLOG",
 		"GetMaintainer - failed to open $DBFILE{$source}.mt\n"
 		);
-	return undef;
+	return 0;
     }
 }
 
-# This routine gets the maintainer object and looks at the auth fields
-# Calls different routines depending on auth method
 sub VrfyMaint {
     local($maintainer, *object) = @_;
     local($status);
     local($source) = $object{"so"};
 
+    print STDERR "VrfyMaint - maintainer: $maintainer\n" if ($opt_V);
+
     if (&GetMaintainer($maintainer, $source,1)) {
 	foreach (split(/\n/, $CurMaintainer{"at"})) {
+	    print STDERR "VrfyMaint - vrfy: $_\n" if ($opt_V);
 	    $status = 0;
 	    if ($_ eq "NONE") {
 		return 1;
@@ -237,11 +203,6 @@ sub VrfyMaint {
 		return 1 if $status;
 		next;
 	    }
-            if ($_ =~ /PGPKEY/) {
-                $status = &CheckPGP($_);
-                return 1 if $status;
-                next;
-            }
 	}
 	return $status;
     }
@@ -259,7 +220,7 @@ sub CheckMailFrom {
     local($regex) = $1;
     $regex =~ s/\\?\@/\Q\@\E/g;   # quote '@'s for perl5
     
-#    &dpr("$FROM=~ /$regex/\n");
+    print STDERR "CheckMailFrom - $FROM=~ /$regex/\n" if ($opt_V);
 
     # case insensitive match
     return 1 if $FROM =~ /$regex/i;
@@ -279,33 +240,6 @@ sub CheckPassword {
     return 0;
 }
 
-#
-# Check PGP authentication
-#
-
-sub CheckPGP {
-   my ($line)=@_;
-   my $key;
-
-   unless ($line =~ /PGPKEY-([0-9a-fA-F]{8})/) {
-     return 0;
-   }
-   $key = $1;
-
-   print "In CheckPGP. Message KEYID = $Main::KEYID, Mntner KEYID = $key\n" 
-       if ($opt_V);
-
-   if (!defined($PGP_signed)) {
-     &syslog("AUDITLOG","Auth PGP failed. (No signature?)");
-     return 0;
-   }
-   if ($PGP_signed ne $key) {
-     &syslog("AUDITLOG","Auth PGP failed. Wrong KEYID: $PGP_signed vs $key");
-     return 0;
-   }
-   return 1;
-}
-
 #
 # This routine will handle the mnt-nfy function in the maintainer object
 # It will extract the email addresses from mnt-nfy attribute, and from
@@ -375,12 +309,12 @@ sub ForwardToMaint {
     
     local($line);
     local(@maintainers) = ();
-    local($oldtype) = &entype(%OldObject);
-    local($newtype) = &entype(%NewObject);
+    local($oldtype) = &entype(*OldObject);
+    local($newtype) = &entype(*NewObject);
     local($source);
     local($email,$regularemail);
     
-#    &dpr("forwarding othermntners=$othermntners\n");
+    print STDERR "ForwardToMaint - forwarding othermntners=$othermntners\n" if $opt_V;
     
     if ($othermntners) {
 
@@ -474,17 +408,9 @@ sub ForwardTmpFile {
 sub WriteForwardHeader {
     local($filehandle, $email) = @_;
 
-    if ($TESTMODE) {
-	$origemail = $email;
-	$email = $DEFMAIL;
-        print $filehandle $FWHEADER, "To: ", $email, "\n";
-        print $filehandle "X-Forward-Orig-Recipient: ", $origemail, "\n\n";
-        print $filehandle $FWTXT;
-    }
-    else {
-        print $filehandle $FWHEADER, "To: ", $email, "\n\n", $FWTXT;
-    }
+    $email = $DEFMAIL if $TESTMODE;
 
+    print $filehandle $FWHEADER, "To: ", $email, "\n\n", $FWTXT;
     
     if ($NETWORKUPDATE) {
        print $filehandle $FWNETWORKTXT, "\n";
