@@ -1,6 +1,6 @@
 #       misc - miscellaneaous functions
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,31 +19,51 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: misc.pl,v 2.21 1999/10/06 11:22:36 marek Exp $
+# $Id: misc.pl,v 2.13 1997/10/21 15:00:35 chris Exp $
 #
 #	$RCSfile: misc.pl,v $
-#	$Revision: 2.21 $
-#	$Author: marek $
-#	$Date: 1999/10/06 11:22:36 $
+#	$Revision: 2.13 $
+#	$Author: chris $
+#	$Date: 1997/10/21 15:00:35 $
 #
 
 require "defines.pl";
-require "dpr.pl";
 
-# sort subroutine for sorting changed fields by date
+# sort block for sorting changed fields
+# needs to cope with 6 or 8 digit dates (YYMMDD or YYYYMMDD)
+# regexp is tied with '$' so they will match 6 LSB digits and ignore
+# century part.
 
 sub sortchangedfield {
-  $a =~ / ((?:\d{2}){3,4})$/;	# matches YYMMDD or YYYYMMDD
-  my($date1) = YYMMDDtoYYYYMMDD($1);
-
-  $b =~ / ((?:\d{2}){3,4})$/;	# matches YYMMDD or YYYYMMDD
-  my($date2) = YYMMDDtoYYYYMMDD($1);
-
-  return 0 unless $date1 || $date2;
-  return -1 unless $date1;
-  return 1 unless $date2;
-
-  return $date1 <=> $date2;
+    
+    $a=~ /(\d{6,6})$/;
+    local($date1)=$1;
+    
+    $b=~ /(\d{6,6})$/;
+    
+    # print STDERR "-$a-$b-$date1-$1-\n";
+      
+    if ((!$date1) && (!$1)) {
+       
+       return 0;
+       
+    }
+    elsif (!$date1) {
+       
+       return -1;
+       
+    }
+    elsif (!$1) {
+       
+       return 1;
+       
+    }
+    else {
+       
+       return $date1 <=> $1;
+    
+    }
+    
 }
 
 sub ReplaceGlobalVars {
@@ -74,10 +94,7 @@ sub ReplaceGlobalVars {
     $text=~ s/\$AUTOBOX/$AUTOBOX/go;
     $text=~ s/\$DATE/$DATE/go;
     $text=~ s/\$TIME/$TIME/go;
-    $text=~ s/\$REFERHOST/$REFERHOST/go;
-    $text=~ s/\$REFERPORT/$REFERPORT/go;
-    $text=~ s/\$REFERMSG/$REFERMSG/go;
-    $text=~ s/\$REFERQUERY/$REFERQUERY/go;
+    
 }
 
 sub MakeRegular {
@@ -451,15 +468,6 @@ sub fullipv6formatprefix {
        if (length($_)>0) {
           s/^0+//;
           $_="0" if (!$_);
-          if(length($_) == 1 && $_ ne '0'){
-            $_ = '000'.$_;
-          }
-          if(length($_) == 2){
-            $_ = '00'.$_;
-          }
-          if(length($_) == 3){
-            $_ = '0'.$_;
-          }
           push(@fields, $_);
           
           $nrofcolons++;
@@ -525,41 +533,19 @@ sub isnet {
 
 # the name says all ...:
 
-sub getYYYYMMDDandHHMMSS {
+sub getYYMMDDandHHMMSS {
 
     local($s,$m,$h,$day,$month,$year,$wd,$yd,$is)=localtime(time);
 
-    $YYYYMMDD=sprintf("%4d%2d%2d",$year + 1900,++$month,$day);
-    $YYYYMMDD=~ s/\D/0/g;
+    $YYMMDD=sprintf("%2d%2d%2d",$year,++$month,$day);
+    $YYMMDD=~ s/\D/0/g;
 
     $HHMMSS=sprintf("%2d:%2d:%2d",$h,$m,$s);
     $HHMMSS=~ s/[^\d:]/0/g;
 
-    print STDERR "$YYYYMMDD $HHMMSS $YEAR\n" if $DEBUG;                    
+    print STDERR "$YYMMDD $HHMMSS $YEAR\n" if $DEBUG;                    
 
-    return ($YYYYMMDD,$HHMMSS);
-}
-
-#  YYMMDDtoYYYYMMDD
-#
-#  converts a date with six digits to y2k-compliant form with 8 digits
-#
-#  assumes that years 00-69 are 2000-2069 and 70-99 are 1970-1999 as the
-#  UNIX calendar starts at 1970 :-)
-#
-#  passes dates which are already in 8 digit form safely through
-
-sub YYMMDDtoYYYYMMDD {
-    my($origdate) = shift;
-
-    if (length($origdate) == 8) {
-      return $origdate;
-    }
-    if (length($origdate) == 6) {
-      return (substr($origdate, 0, 2) < 70 ? '20' : '19') . $origdate;
-    }
-    &syslog("ERRLOG", "YYMMDDtoYYYYMMDD: illegal date \"$origdate\"");
-    return undef;
+    return ($YYMMDD,$HHMMSS);
 }
 
 # 
@@ -587,7 +573,7 @@ sub YYMMDDtoYYYYMMDD {
 
 sub isasnum {
     
-    return scalar(($_[0]=~ /^AS([1-9]+\d*)$/) && ($1 > 0) && ($1 < 65536));
+    return scalar(($_[0]=~ /^AS([1-9]+\d*)/) && ($1 > 0) && ($1 < 65536));
     
 }
 
@@ -645,9 +631,6 @@ sub isnichandle {
     #    - country codes are allowed for APNIC compatibility
     #    - APNIC AP|CC-AU exceptions are handled correctly
     #    - -ORG organization InterNIC handles
-    #    - -ARIN ARIN handles
-    #    - -ORG-ARIN ARIN handles
-    #    - -RIPN RIPN handles
     
   my $handle = shift;
   
@@ -671,9 +654,6 @@ sub isnichandle {
   # APNIC use two letter country code suffix
   # Austraila have used -1-AU, -2-AU, -CC-AU suffix.
   # Internic used -ORG suffix
-  # ARIN use -ARIN suffix
-  # ARIN also use -ORG-ARIN suffix
-  # RIPN use -RIPN suffix
   #
   
   if ($handle =~ /^([A-Z]{2,$MAXLENGTHINITIALS})([1-9]\d{0,5})?(-\S+)?$/) {
@@ -701,9 +681,6 @@ sub isnichandle {
 		 ($suffix eq '1-AU') ||
 		 ($suffix eq '2-AU') ||
 		 ($suffix eq 'ORG') ||
-                 ($suffix eq 'ARIN') ||
-                 ($suffix eq 'ORG-ARIN') ||
-		 ($suffix eq 'RIPN') ||
 		 ($suffix eq 'AP')
 		 );
   }
@@ -965,7 +942,7 @@ sub isname {
 sub isphone {
     
     return scalar(($_[0] =~ /^\s*\+\s*\(?\s*\d+\s*\)?\s*(\s*[\-\.\(]*\s*\d+\s*\)?\s*)*(\s*ext\.\s*\d+\s*)?$/i) &&
-            (&isparen($_[0])));
+            (&isbrace($_[0])));
     
 }
 
@@ -993,19 +970,13 @@ sub isemail {
 
 }
 
-# check for matching curly braces (was previously isbracket but
-# bracets are [] as far as I know :-) //snabb 980928
-
-sub isbrace {
+sub isbracket {
     
     return ($_[0]=~ s/\{/\{/g==$_[0]=~ s/\}/\}/g);
     
 }
 
-# check for matching parentheses (was previously isbrace but
-# braces are {}...) //snabb 980928
-
-sub isparen {
+sub isbrace {
    
     return ($_[0]=~ s/\(/\(/g==$_[0]=~ s/\)/\)/g);
 
@@ -1057,10 +1028,10 @@ sub unlock {
     sub lower_priority {
 
       if (defined $RENICECMD) {
-#	&dpr("using [$RENICECMD]\n");
+	print STDERR "using [$RENICECMD]\n" if $opt_V;
 	return system("$RENICECMD 10 $$ > /dev/null 2>/dev/null");
       } else {
-#	&dpr("using setpriority(2)\n");
+	print STDERR "using setpriority(2)\n" if $opt_V;
 	return setpriority PRIO_PROCESS, 0, $nice_value;
       }
     }
