@@ -1,6 +1,6 @@
 # net2net.pl
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,18 +19,17 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: net2net.pl,v 2.8 1999/08/23 16:49:26 marek Exp $
+# $Id: net2net.pl,v 2.5 1997/10/17 11:15:16 chris Exp $
 #
 #	$RCSfile: net2net.pl,v $
-#	$Revision: 2.8 $
-#	$Author: marek $
-#	$Date: 1999/08/23 16:49:26 $
+#	$Revision: 2.5 $
+#	$Author: chris $
+#	$Date: 1997/10/17 11:15:16 $
 #
 
 require "defines.pl";
 require "syslog.pl";
 require "misc.pl";
-require "dpr.pl";
 
 # 
 # The quad2int & int2quad routines are completely rewritten
@@ -77,27 +76,10 @@ sub quad2int {
 #
 # int int2quad(quad)
 #
-# given (long) integer returns a string representing it as an IP address style
-# dotted quad.
 
 sub int2quad {
-  use strict;
 
-  my($int)=@_;
-
-  # nasty hack to make perl treat the integer as a numeric rather than a 
-  # string. (see also iprightzeromask in misc.pl)
-  #
-  # just do a simple arithmetic operation on it - decrement then increment
-  # unless it's zero.
-
-  if ($int == 0) {
-    $int++; $int--;
-  } else {
-    $int--; $int++;
-  }
-
-  return join('.', unpack('C4',pack('N',$int)));
+  return join(".", unpack(C4,pack(N,$_[0])));
 }
 
 # convert range in form 'a.b.c.d - a.b.255.255'
@@ -151,19 +133,19 @@ sub completeip {
     
     local($nrofdots)= $range=~ s/\./\./g;
     
-    &dpr( "range $range $nrofdots\n");
+    # print STDERR "range $range $nrofdots\n";
     
     $range=join("", $range, (".0") x (3 - $nrofdots)) if ($nrofdots<3);
     
     # remove leading zeros and check if we have a valid ip
     
-    &dpr( $range, "\n");
+    # print STDERR $range, "\n";
     
     local($int);
     
     if (($int=&quad2int($range,0))>=0) {
        
-       &dpr( $int, "\n");
+       # print STDERR $int, "\n";
        
        return (&int2quad($int),$int);
        
@@ -181,7 +163,7 @@ sub normalizerange {
     
     local($ip1);
     
-    &dpr("normalizerange - type: $type range: $range\n") if ($range=~ /\-/);
+    # print STDERR "normalizerange - type: $type range: $range\n" if ($range=~ /\-/);
     
     if ($range=~ /^(\d+)(\.[\.\d]*)? *([\/\-]) *([\d\.]+)*$/) {
        
@@ -197,7 +179,7 @@ sub normalizerange {
        
           return ("", $O_INVALIDIP) if ($ip1<0);
        
-          &dpr("normalizerange - mask: ", ~$masks[$len], " prefix: $range len: $len\n");
+          # print STDERR "normalizerange - mask: ", ~$masks[$len], " prefix: $range len: $len\n" if $opt_V;
        
           if (($len=~ /^0*([12]?[\d]|3[012])$/) && 
               (!($ip1 & (~$masks[$len])))) {
@@ -217,24 +199,24 @@ sub normalizerange {
        
           local($ip2);
        
-          &dpr("normalizerange - type $type from: $range to: $torange\n");
+          # print STDERR "normalizerange - type $type from: $range to: $torange\n";
        
           ($torange,$ip2)=&completeip($torange);
        
-          &dpr("normalizerange - type $type from: $range to: $torange\n");
+          # print STDERR "normalizerange - type $type from: $range to: $torange\n";
        
           return ("", $O_INVALIDRANGE) if ($ip2<$ip1);
           return ("", $O_INVALIDIP) if (($ip1<0) || ($ip2<0));
        
-          if ($torange=~ /^(\d+)\.\d+\.\d+\.0$/ && $ip2 != $ip1) {
+          if ($torange=~ /^(\d+)\.\d+\.\d+\.0$/) {
           
              if ($1>=192) {
                 
-                &dpr("normalizerange - type $type from: $range to: $torange\n");
+                # print STDERR "normalizerange - type $type from: $range to: $torange\n";
                 
                 $torange=~ s/\.0$/\.255/;
                 
-                &dpr("normalizerange - type $type from: $range to: $torange\n");
+                # print STDERR "normalizerange - type $type from: $range to: $torange\n";
              
              }
              elsif ($1>=128) {
@@ -244,7 +226,7 @@ sub normalizerange {
              }
              else {
              
-                $torange=~ s/\.0\.0\.0$/\.255\.255\.255/;
+                $torange=$1.".255.255.255";
              
              }
           
@@ -263,7 +245,7 @@ sub normalizerange {
        
        return ("", $O_INVALIDIP) if ($ip1<0);
        
-       &dpr("normalizerange - type $type range: $range\n");
+       # print STDERR "normalizerange - type $type range: $range\n" if $opt_V;
        
        # note that the order in the comparisons is important
        # *and* the order of the if's is important !!!
