@@ -1,6 +1,6 @@
 # newdb.pl
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: newdb.pl,v 2.7 1999/03/18 15:08:11 marek Exp $
+# $Id: newdb.pl,v 2.2 1997/10/02 15:26:00 chris Exp $
 #
 #	$RCSfile: newdb.pl,v $
-#	$Revision: 2.7 $
-#	$Author: marek $
-#	$Date: 1999/03/18 15:08:11 $
+#	$Revision: 2.2 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:26:00 $
 
 # This is a little tool to generate an empty database which just contains
 # the generation date, and the COPYRIGHT notice as defined in the config
@@ -32,24 +32,19 @@
 # One should be careful with this, since it will simply overwrite existing
 # database files if the -f flag is given. No Mercy.
 
-use DB_File;
-
 require "rconf.pl";
 require "getopts.pl";
 
-&Getopts('fab');
+&Getopts('f');
 
 # You need help or have no command line arguments ?
 
-if ((scalar @ARGV)==0 && $opt_a != 1) {
+if (!$ARGV[0]) {
 	print <<"EOF";
 
 Usage: $0 [-f] file
-       $0 -a [source]
 
 -f		Force new database even if file exists
--a		Create all new databases
--b              Print a lot of useless debugging information
 filename	The name of the new database file to be generated
 
 EOF
@@ -57,75 +52,37 @@ EOF
 	exit;
 }
 
+# Check to see if file exists, and if the force overwrite flag is set
 
-# Read the configuration
+if (-e $ARGV[0] && !$opt_f) {
+   print STDERR "File exists, will not overwrite\n";
+   exit;
+}
+
+# Read the conf, for the COPYRIGHT notice
 
 $conffile=$ENV{"RIPEDBCNF"};
-$conffile=$RIPEConfig{DEFCONFIG} unless $conffile;
+$conffile= $RIPEConfig{DEFCONFIG} unless $conffile;
 &rconf($conffile);
 
 # Here we go ...
-if( $opt_a )
-{
-	$DBSOURCE = $ARGV[0] ? $ARGV[0] : $DEFLOOK;
 
-	if( $SPLIT{$DBSOURCE} != 1) {
-	  die "the database $DBSOURCE is not SPLIT. No files to create\n";
-	}
-
-	if( $DBFILE{$DBSOURCE} eq '' ) {
-	  &fatalerror("location of database not found in config file");
-	}
-        $nd_filename_prefix=$DBFILE{$DBSOURCE};
-
-	foreach $nd_obj_name ( sort keys %OBJATSQ )
-	{
-	  print "Doing $nd_obj_name";
-	  $newdbname = lc "$nd_filename_prefix.$nd_obj_name";
-	  print "..creating $newdbname\n";
-	  &createnewdb( $newdbname )
-	}
-}
-else
-{
-	$newdbname = $ARGV[0];
-	print "..creating $newdbname\n";
-	&createnewdb( $newdbname )
-}
-
-# done.
-exit;
-
-###########################################################################
-
-sub createnewdb
-{
-local($newdbname)=@_;
-local(%hash,$newdbidxname);
-
-# Check to see if file exists, and if the force overwrite flag is set
-	if (-e $newdbname && !$opt_f) {
-	   print STDERR "File exists, will not overwrite\n";
-	   return;
-	}
+open(NEWDB, ">".$ARGV[0]) || &fatalerror("Cannot open $ARGV[0]: $!");
 
 # Print generation date and copyright to the database
 #
 # printright is required since addkey doesn\'t work
 # correct when an offset==0
 
-open(NEWDB, ">".$newdbname) || &fatalerror("Cannot open $newdbname: $!");
 &printrights(NEWDB);
+
+# And that was it ...
+
 close(NEWDB);
 
 # Delete indexes in case they happen to exist ...
-&delormoveindices($newdbname, "", 0);
-&delormoveindices($newdbname.$CLASSLESSEXT, "", 1);
 
-# (Re)create empty index file
-  %hash=(); 
-  $newdbidxname=$newdbname.".db";
-  tie (%hash, DB_File, $newdbidxname, O_RDWR|O_CREAT,0644,$DB_HASH) 
-	|| &fatalerror("cannot create index file $newdbidxname : $!"); 
+&delormoveindices($ARGV[0], "", 0);
+&delormoveindices($ARGV[0].$CLASSLESSEXT, "", 1);
 
-}
+# end of script
