@@ -1,6 +1,6 @@
 # notify.pl - implements the notify function.
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,18 +19,17 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: notify.pl,v 2.10 1999/05/31 14:45:31 roman Exp $
+# $Id: notify.pl,v 2.6 1997/10/02 15:26:01 chris Exp $
 #
 #	$RCSfile: notify.pl,v $
-#	$Revision: 2.10 $
-#	$Author: roman $
-#	$Date: 1999/05/31 14:45:31 $
+#	$Revision: 2.6 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:26:01 $
 
 
 require "encmp.pl";
 require "enwrite.pl";
 require "entype.pl";
-require "dpr.pl";
 
 # It consists of two parts. One is the part that writes out the objects
 # to temp files, one temp file per notifier, and this is called from
@@ -99,7 +98,7 @@ sub DoAddNotify {
 
     foreach $notify (@notifiers) {
         
-#        &dpr("notifier: $notify\n");
+        print STDERR "notifier: $notify\n" if ($opt_V);
         
         #
         # skip doubles
@@ -118,12 +117,13 @@ sub DoAddNotify {
 
 	  my ($match) = ($REPLYTO=~ /$regularnotify/);
 
-#	  &dpr("DoAddNotify: ",
-#	       "notifiee [$notify], ",
-#	       "sender [$REPLYTO], ",
-#	       "regexp [$regularnotify]",
-#	       "match [$match]",
-#	       "\n");
+	  print STDERR "DoAddNotify: ",
+	               "notifiee [$notify], ",
+	               "sender [$REPLYTO], ",
+	               "regexp [$regularnotify]",
+	               "match [$match]",
+	               "\n"
+			 if $opt_V;
 
 	  if ($match) {
 	    if ($SUPPRESSMESS eq 'NOTIFY') {    # suppress notification
@@ -186,16 +186,9 @@ sub NotifyTmpFile {
 sub WriteNotifyHeader {
     local($filehandle, $notifier)=@_;
 
-    if ($TESTMODE) {
-	$orignotifier = $notifier;
-	$notifier=$DEFMAIL;
-	print $filehandle $NHEADER, "To: ", $notifier, "\n";
-	print $filehandle "X-Notify_Orig_Recipient: ", $orignotifier, "\n\n";
-	print $filehandle $NOTITXT;
-    }
-    else {
-        print $filehandle $NHEADER, "To: ", $notifier, "\n\n", $NOTITXT;
-    }
+    $notifier=$DEFMAIL if $TESTMODE;
+    
+    print $filehandle $NHEADER, "To: ", $notifier, "\n\n", $NOTITXT;
     
     if ($NETWORKUPDATE) {
        print $filehandle $NOTINETWORKTXT, "\n";
@@ -212,7 +205,7 @@ sub SendNotifications {
 
     foreach (values %notify) {
        system("$MAILCMD < $_");
-#       &dpr("notify: $_\n");
+       print STDERR "notify: $_\n" if ($opt_V);
     }
     
     unlink(values %notify);
