@@ -1,6 +1,6 @@
 # processdata.pl 
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: processdata.pl,v 2.17 1999/10/05 14:49:12 marek Exp $
+# $Id: processdata.pl,v 2.6 1997/10/02 15:26:02 chris Exp $
 #
 #	$RCSfile: processdata.pl,v $
-#	$Revision: 2.17 $
-#	$Author: marek $
-#	$Date: 1999/10/05 14:49:12 $
+#	$Revision: 2.6 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:26:02 $
 
 
 @INC = ("LIBDIR", @INC);
@@ -41,7 +41,6 @@ require "misc.pl";
 require "rconf.pl";
 require "rfc822.pl";
 require "syslog.pl";
-require "dpr.pl";
 
 
 #
@@ -53,6 +52,8 @@ require "dpr.pl";
 sub printstat {
     local($output, *entry, $type, $options) = @_;
 
+    print STDERR "dbupdate - printstat($FROM,$options) called\n" if $opt_V;
+
     if ($options & $DELETEOPTION) {
        print $output "Delete ";
     }
@@ -108,25 +109,27 @@ sub processdata {
     local($type,$key,$value,$reordered,$dbstat,$parsestat);
     local($options,$codes,$overrideattr,$deleteattr,@autonichandles);
 
-    &dpr("\$FROM = $FROM, \$input = $input, \$output = $output\n");
+    print STDERR "processdata - ($FROM,$input) called\n" if $opt_V;
     
     while(1) {
 
+	print STDERR "processdata - calling enparse\n" if $opt_V;
+        
 	($parsestat, $type, %entry)=&enparse($input) if (!$eof);
 	
-#	&dpr("enparse returned: \$parsestat = $parsestat, \$type = $type\n");
-#	&dpr("+++++++++++++++++++++++++++\n");
-#	&dpr("\%entry = " . join("*", %entry) . "\n");
-#	&dpr("---------------------------\n");
+	print STDERR "processdata - left parse: $parsestat $type\n" if ($opt_V);
 	
 	$eof=1 if ($parsestat==$EOF);
 	
+	#
 	# get objects from the queue if we reached EOF
 	
 	if ($eof) {
 	   
 	   if (@queue) {
 	      
+	      # print STDERR "queue:\n", join("\n", @queue), "-\n";
+	      
 	      $parsestat=shift(@queue);
 	      $type=shift(@queue);
 	      @autonichandles=split(" ", shift(@queue));
@@ -139,6 +142,7 @@ sub processdata {
 	          
 	      }
 	      
+	      
 	   }
 	   else {
 	      
@@ -156,7 +160,7 @@ sub processdata {
         
         $somethingfound=1;
         
-#	&dpr("read an object ($parsestat,$entry{$type})\n");
+	print STDERR "dbupdate - read an object ($parsestat,$entry{$type})\n" if $opt_V;
 
         if ($parsestat==$O_ERROR) {
            
@@ -175,14 +179,13 @@ sub processdata {
 	   }
 	
 	   if (defined($entry{"uo"})) {
-	       &dpr("override entry: ".$entry{"uo"}."\n");
-	       $options |= $OVERRIDEOPTION;
-	       $options |= $OVERRIDEINTEGRITY 
-		   if ($entry{"uo"} =~ /integrity/i);
-	       $overrideattr = delete($entry{"uo"});
+	
+	      $options|=$OVERRIDEOPTION;
+	      $overrideattr=delete($entry{"uo"});
+	                    
 	   }
 	   else {
-	      $overrideattr = undef;
+	      $overrideattr=undef;
 	   }
            
         }
@@ -301,11 +304,10 @@ sub processdata {
 	   }
 	
 	   if (defined($entry{"uo"})) {
-	       &dpr("override entry: ".$entry{"uo"}."\n");
-	       $options |= $OVERRIDEOPTION;
-	       $options |= $OVERRIDEINTEGRITY 
-		   if ($entry{"uo"} =~ /integrity/i);
-	       $overrideattr = delete($entry{"uo"});
+	
+	      $options|=$OVERRIDEOPTION;
+	      $overrideattr=delete($entry{"uo"});
+	                    
 	   }
         
            #
@@ -314,9 +316,8 @@ sub processdata {
 	
 	   ($dbstat, $codes) =&finalchecksandupdate(*entry, $type, *autonichandles, *options);
 	   
-#	   &dpr("left ($FROM,$dbstat, $codes)\n");
-
-
+	   print STDERR "finalchecksandupdate - left ($FROM,$dbstat, $codes)\n" if ($opt_V);
+	    
 	}
 	
 	# print STDERR %entry, "\n";
@@ -335,7 +336,7 @@ sub processdata {
 	}
 	elsif (($dbstat!=$O_ERROR) && ($dbstat!=$O_OK) && ($dbstat!=$E_NOOP)) { 
 	      
-	    &adderror(*entry, eval $MESSAGE[$dbstat]);
+	    &adderror(*entry, $MESSAGE[$dbstat]);
 	     
 	    $haserror++;
 	      
@@ -365,7 +366,7 @@ sub processdata {
 	}
 	elsif (&haserror(*entry)) {
 	
-#	   &dpr("object has error\n");
+	   print STDERR "dbupdate - object has error\n" if $opt_V;
 	   
 	   $haserror++;
 	   
@@ -377,7 +378,7 @@ sub processdata {
 	elsif (&haswarning(*entry)) {
 	   
 	   &printstat($output, *entry, $type, $options | $OKOPTION);
- 	   &enwrite($output,*entry,1,1,1);
+	   &enwrite($output,*entry,1,1,1);
 	   print $output "\n";
 	   
 	}
@@ -400,128 +401,19 @@ sub processdata {
 sub dbupdate {
     local($input, $output)=@_;
     
-    # Set a global variable to mark this as an update
+    #
+    # We want to make a local copy of the input, because we need to do multiple
+    # things with it ...
 
-    $Main::is_update=1;
-
-    # We want to make a local copy of the input, because we need to do
-    # multiple things with it... also we want to separate PGP signed
-    # parts from the original message to be fed to PGPV for checking.
-
-    my($copyfile_unsigned) = $TMPDIR . "/dbupdcopy.$$";
-    my(@copyfiles_signed);
-
-    open(COPY, "+>$copyfile_unsigned")
-	or fatalerror("Cannot create $copyfile_unsigned: $!");
-
-    my(@input);
-
-    if ($input) {
-      @input = split(/\n/, $input);
-    } 
-
-    # log a copy of the message to UPDLOG before we process it
-
-    # This may seem yucky, but is needed to untaint the filename ...
-    {
-      my($filename) = $LOGFILE{"UPDLOG"}."/".$DATE;
-      $filename =~ /(.*)/;
-      $realfile = $1;
-    }
-
-    if (open(LOG, ">>$realfile")) {
-      &appendlock(LOG);
+    local($copyfilename)=$TMPDIR."\/dbupdcopy.".$$;
     
-      if ($opt_M) {
-        print LOG "\n>>> time: $TIME MAIL UPDATE <<<\n\n";
-      } 
-      elsif ($NETWORKUPDATE) {
-        print LOG "\n>>> time: $TIME $NETWORKUPDATE NETWORK UPDATE <<<\n\n";
-      }
-      else {
-        print LOG "\n>>> time: $TIME STDIN UPDATE <<<\n\n";
-      }
+    open(COPY, "+>".$copyfilename) || &fatalerror("Cannot create $copyfilename: $!");
+    if ($input) {
+       print COPY $input;
     }
     else {
-      &syslog("ERRLOG", "dbupdate cannot open $realfile"); 
-      print STDERR "dbupdate cannot open $realfile";
-      exit 75;
+       print COPY <>;
     }
-
-    my($cpst) = 0; # 0 = unsigned, 1 = signed data, 2 = signature
-		   # 3 = encoded message
-
-    while (1) {
-      if ($input) {
-	last unless defined($_ = shift(@input));
-	$_ .= "\n";	# split above eats new-lines
-      } else {
-	last unless defined($_ = <>);
-      }
-      print LOG;
-
-      unless ($have_pgp) {
-	print COPY;
-	next;
-      }
-      if ($cpst == 0 && /^-----BEGIN PGP SIGNED MESSAGE-----$/) {
-	$cpst = 1;
-
-	my($copyfile_signed) = $TMPDIR . "/dbupdscopy.$$." . @copyfiles_signed;
-	push(@copyfiles_signed, $copyfile_signed);
-
-	open(PGPCOPY, ">$copyfile_signed")
-	    or fatalerror("Cannot create $copyfile_signed: $!");
-
-	# fall through
-      }
-      if ($cpst == 0 && /^-----BEGIN PGP MESSAGE-----$/) {
-	$cpst = 3;
-
-	my($copyfile_signed) = $TMPDIR . "/dbupdscopy.$$." . @copyfiles_signed;
-	push(@copyfiles_signed, $copyfile_signed);
-
-	open(PGPCOPY, ">$copyfile_signed")
-	    or fatalerror("Cannot create $copyfile_signed: $!");
-
-	# fall through
-      }
-      if ($cpst == 0) {
-	print COPY;
-	next;
-      }
-      if ($cpst == 1 && /^-----BEGIN PGP SIGNATURE-----$/) {
-	$cpst = 2;
-	# fall through
-      }
-      if ($cpst == 2 && /^-----END PGP SIGNATURE-----$/) {
-	$cpst = 0;
-	print PGPCOPY;
-	close(PGPCOPY);
-	next;
-      }
-      if ($cpst == 3 && /^-----END PGP MESSAGE-----$/) {
-	$cpst = 0;
-	print PGPCOPY;
-	close(PGPCOPY);
-	next;
-      }
-      if ($cpst == 1 || $cpst == 2 || $cpst == 3) {
-	print PGPCOPY;
-	next;
-      }
-      fatalerror("Unknown cpst state: $cpst (should not happen)");
-      last; # not reached?
-    }
-
-    # discard (last) signed part if it is not properly finished
-    if ($cpst != 0) {
-      close(PGPCOPY);
-      unlink(pop(@copyfiles_signed));
-    }
-
-    close(LOG);
-
     &flush(COPY);
     seek(COPY, 0, 0);
 
@@ -547,10 +439,9 @@ sub dbupdate {
     # We have a mail, so let's first parse the headers ...
 
     local($stat)=1;
-    undef @subj_ans;
 
     $stat=&parserfc822(COPY) if ((!$opt_m) && ($opt_M));
-
+    
     &ReplaceGlobalVars(*FWHEADER);
     &ReplaceGlobalVars(*FWTXT);
     &ReplaceGlobalVars(*FWMAILTXT);
@@ -577,137 +468,21 @@ sub dbupdate {
     # if Help was requested just reply with the help
     # don't parse the body of the message
 
-    # $HELPREQUESTED is set in parserfc822
-    # so if it is set we are definately in mail mode
     if ($HELPREQUESTED) {
    
-      push @ack, "To: $REPLYTO\n";
-
       push @ack, $HELPHEADER, "\n";
 	 
-      open(HELP, "<".$AUTODBMHELP);
+      open(HELP, "<".$HELP);
       push @ack, "=" x 60, "\n\n", <HELP>, "\n", "=" x 60, "\n";
       close(HELP);
       
     } else {
 
-      #
-      # PGP signature state: undef if not signed, keyID if signed & ok
-      #
-
-      $PGP_signed = undef;
-
       #
       # Take all the stuff from file COPY in doaction. It will process the
       # whole stuff.
-      #
 
-      my($somethingfound, $haserror) = processdata(COPY, ACK);
-      close(COPY);
-
-      #
-      # Then we process the PGP signed parts
-      #
-
-      foreach $copyfile_signed (@copyfiles_signed) {
-	my($copyfile_signed_out) = $TMPDIR . "/dbupdscopyo.$$";
-	my($somethingfound_new, $haserror_new);
-
-	my($pgpsigstatus, $pgpsigid) = 
-	    checkPGPmsg($copyfile_signed, $copyfile_signed_out);
-
-	if (!defined($pgpsigstatus) || $pgpsigstatus == -1) { 
-	  # no signature found by PGP or PGP error
-	  # process the part as w/o signature (shouldn't happen?)
-          $PGP_signed = undef;
-
-	  if ($pgpsigstatus == -1) {
-	    print ACK "*** Cannot check PGP signed part: $pgpsigid\n\n";
-	    $haserror = $somethingfound = 1;
-	  }
-
-          open(SCOPY, $copyfile_signed)
-	      or fatalerror("Cannot open $copyfile_signed: $!");
-
-	  ($somethingfound_new, $haserror_new) = processdata(SCOPY, ACK);
-	  close(SCOPY);
-           
-	  $somethingfound = $somethingfound_new if $somethingfound_new;
-	  $haserror = $haserror_new if $haserror_new;
-	} elsif ($pgpsigstatus == 0) { # PGP signature not OK, ignore this part
-          $PGP_signed = undef;
-
-	  print ACK "*** Ignoring PGP signed part with BAD signature"
-	      . ($pgpsigid ? " from key ID $pgpsigid" : "") . "\n\n";
-	  $haserror = $somethingfound = 1;
-
-	} elsif ($pgpsigstatus == 1) { # signature by unknown keyID
-	  $PGP_signed = undef;
-
-	  print ACK "*** Beginning of PGP signed part "
-	      . "from *UNKNOWN* key ID $pgpsigid\n\n";
-	  $haserror = $somethingfound = 1;
-
-          open(SCOPY, $copyfile_signed_out)
-	      or fatalerror("Cannot open $copyfile_signed_out: $!");
-
-	  ($somethingfound_new, $haserror_new) = processdata(SCOPY, ACK);
-	  close(SCOPY);
-           
-	  $somethingfound = $somethingfound_new if $somethingfound_new;
-	  $haserror = $haserror_new if $haserror_new;
-
-	  print ACK "*** End of PGP signed part "
-	      . "from *UNKNOWN* key ID $pgpsigid\n\n";
-
-	} elsif ($pgpsigstatus == 2) { # PGP signature OK
-          $PGP_signed = $pgpsigid;
-
-	  print ACK "*** Beginning of PGP signed part "
-	      . "from key ID $pgpsigid\n\n";
-	  $somethingfound = 1;
-
-          open(SCOPY, $copyfile_signed_out)
-	      or fatalerror("Cannot open $copyfile_signed_out: $!");
-
-	  ($somethingfound_new, $haserror_new) = processdata(SCOPY, ACK);
-	  close(SCOPY);
-           
-	  $somethingfound = $somethingfound_new if $somethingfound_new;
-	  $haserror = $haserror_new if $haserror_new;
-
-	  print ACK "*** End of PGP signed part "
-	      . "from key ID $pgpsigid\n\n";
-
-	} elsif ($pgpsigstatus == 3) { # message encrypted & can't decrypt
-          $PGP_signed = undef;
-
-	  print ACK "*** Ignoring PGP encrypted part (can't decrypt)\n\n";
-	  $haserror = $somethingfound = 1;
-
-	} elsif ($pgpsigstatus == 4) { # message encrypted & can decrypt
-          $PGP_signed = undef;
-
-	  print ACK "*** Beginning of PGP encrypted part\n\n";
-	  $haserror = $somethingfound = 1;
-
-          open(SCOPY, $copyfile_signed_out)
-	      or fatalerror("Cannot open $copyfile_signed_out: $!");
-
-	  ($somethingfound_new, $haserror_new) = processdata(SCOPY, ACK);
-	  close(SCOPY);
-           
-	  $somethingfound = $somethingfound_new if $somethingfound_new;
-	  $haserror = $haserror_new if $haserror_new;
-
-	  print ACK "*** End of PGP encrypted part\n\n";
-
-	} else { # shouldn't ever happen :-)
-          fatalerror("Unknown PGP sig state: $pgpsigstatus (shouldn't happen)");
-	}
-	unlink($copyfile_signed_out);
-	$PGP_signed = undef;
-      }
+      local($somethingfound, $haserror)=&processdata(COPY, ACK);
 
       # rewind the ack file generated by processdata
       &flush(ACK);
@@ -721,7 +496,6 @@ sub dbupdate {
 
   	  if ($TESTMODE) {
 	    push @ack, "To: ", $DEFMAIL, "\n";
-	    push @ack, "X-Ack-Orig-Recipient: ", $REPLYTO, "\n";
 	  }
 	  else {
 	    #
@@ -761,8 +535,7 @@ sub dbupdate {
       } else {
 	push @ack, "*** No objects were found ***\n" unless ($NETWORKUPDATE);
       }
-      # include diagnostics from Subject: parser
-      push @ack, @subj_ans;    
+
     }
 
 #    if ($somethingfound) {
@@ -788,21 +561,53 @@ sub dbupdate {
     # We sent out the ack, now send out the notifications if needed
 
     if (%notify) {
-#       &dpr("sending notifications (", keys %notify,")\n");
+       print STDERR "dbupdate - sending notifications (", keys %notify,")\n" if ($opt_V);
        &SendNotifications();
     }
 
-    # send out cross notifications
-
-    if (@::cross_notification_mailfiles) {
-      send_cross_notifications(@::cross_notification_mailfiles);
-    }
-
     if (%forward) {
-#       &dpr("sending forwards(", keys %forward, ")\n");
+       print STDERR "dbupdate - sending forwards(", keys %forward, ")\n" if ($opt_V);
        &SendForwardMails();
     }
 
+    #
+    # log all stuff to the right places
+
+    # This may seem yucky, but is needed to untaint the filename ...
+
+    $filename = $LOGFILE{"UPDLOG"}."/".$DATE;
+    $filename =~ /(.*)/;
+    $realfile = $1;
+
+    #
+    # first let's log the updates send in
+
+    if (open(LOG, ">>$realfile")) {
+    
+       &appendlock(LOG);
+    
+       if ($opt_M) {
+          print LOG "\n>>> time: $TIME MAIL UPDATE <<<\n\n";
+       } 
+       elsif ($NETWORKUPDATE) {
+          print LOG "\n>>> time: $TIME $NETWORKUPDATE NETWORK UPDATE <<<\n\n";
+       }
+       else {
+          print LOG "\n>>> time: $TIME STDIN UPDATE <<<\n\n";
+       }
+
+       &flush(COPY);
+       seek(COPY, 0, 0);
+       print LOG <COPY>;
+       close(LOG);
+   
+    }
+    else {
+      &syslog("ERRLOG", "dbupdate cannot open $LOGFILE{\"UPDLOG\"}/$DATE"); 
+    }
+
+    close(COPY);
+
     #
     # then we log the acknowledgement
 
@@ -812,7 +617,7 @@ sub dbupdate {
 
     if (open(LOG, ">>$realfile")) {
     
-#       &dpr("updating logs\n");
+       print STDERR "dbupdate - updating logs\n" if $opt_V;
     
        &appendlock(LOG);
     
@@ -849,25 +654,26 @@ sub dbupdate {
     # unless we have send a notify to the same address
 
     if ($opt_M) {
-	if ($::DontAck) {
-#	    &dpr("dbupdate - notification to [$REPLYTO] ",
-#		 "suppresses ack to [$::DontAck]\n");
-	    undef $::DontAck;
-	} else {
-#	    &dpr("dbupdate - sending ack\n");
+      if ($::DontAck) {
+	print STDERR "dbupdate - notification to [$REPLYTO] ",
+	             "suppresses ack to [$::DontAck]\n"
+		       if $opt_V;
+	undef $::DontAck;
+      } else {
+	print STDERR "dbupdate - sending ack\n" if $opt_V;
 #	system("$MAILCMD <".$ackfilename);
-	    open(MAIL, "|$MAILCMD");
+	open(MAIL, "|$MAILCMD");
 #	open(MAIL, "|/bin/cat");
-	    print MAIL @ack;
-	    close MAIL || warn "mail: $!"
+	print MAIL @ack;
+	close MAIL || warn "mail: $!"
 #	system("/bin/cat <".$ackfilename);
-	    }
+      }
     }
     
     #
     # remove the temp stuff we made
 
-    unlink($copyfile_unsigned, $ackfilename, @copyfiles_signed);
+    unlink($copyfilename, $ackfilename);
 
 }
 
