@@ -1,6 +1,6 @@
 # rconf.pl - read configuration file
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: rconf.pl,v 2.18 1999/10/05 14:45:15 marek Exp $
+# $Id: rconf.pl,v 2.7 1997/10/17 11:16:04 chris Exp $
 #
 #	$RCSfile: rconf.pl,v $
-#	$Revision: 2.18 $
-#	$Author: marek $
-#	$Date: 1999/10/05 14:45:15 $
+#	$Revision: 2.7 $
+#	$Author: chris $
+#	$Date: 1997/10/17 11:16:04 $
 #
 #       This routine reads all parameters from the configuration file
 #       into scalars or associative arrays of the same name (uppercase).
@@ -47,6 +47,8 @@ require "read_objs.pl";
 sub rconf {
     local($confname) = @_;
 
+    local ($i);
+
     #
     # set the program name correctly
 
@@ -61,50 +63,24 @@ sub rconf {
     #
     # needed in several routines...
     
-    ($DATE,$TIME)=&getYYYYMMDDandHHMMSS(); 
+    ($DATE,$TIME)=&getYYMMDDandHHMMSS(); 
     
     #
     # set a safe umask
     
     umask(022);
-
-    rconfreadfile($confname);
-
-    rconfprocess();
-}
-
-sub rconfreadfile {
-    my($confname) = @_;
-    my($i);
-    my($newconf);
-    local *CONF;
     
     open(CONF, $confname) || &fatalerror("rconf: cannot open config \"$confname\", $!");
 
-    # print STDERR "Reading configuration from $confname\n";
-
     while (<CONF>) {
 	
 	study $_;
-
+	
 	next if (/^\#/);
 	next if (/^\s*$/);
-
-	# print STDERR "++++ $_";
-		
+	
 	last if (/^ENDCONF/);
 
-	if (/^INCLUDE\s+(\S+)/) {
-	    $newconf=$1;
-	    if($newconf !~ m|/|)
-		{
-		$newconf=substr($confname,0,rindex($confname,"/")+1) . $newconf;
-		}
-	    &rconfreadfile($newconf);	    
-	    next;
-	}
-
-
         if (/^COUNTRY\s+(..)\s+(..)/) { 
 	    $COUNTRY{$1}=$1; $COUNTRY{$2}=$1; 
 	    next;
@@ -112,8 +88,8 @@ sub rconfreadfile {
 
         if (s/^OBJ\s+(\S\S)\s+(\S+)\s+//) {
            
-           my $type=$1;
-           my $field=$2;
+           $type=$1;
+           $field=$2;
            
            s/\s+/ /g;
            s/ $//;
@@ -183,14 +159,6 @@ sub rconfreadfile {
 	      else {
 		 $INV{$type}=$_;
 	      }
-           }
-           elsif ($field eq "GEN") {
-             if ($GEN{$type}) {
-                $GEN{$type}=join(" ", $GEN{$type}, $_);
-             }
-             else {
-                $GEN{$type}=$_;
-             }
 	   }
            
            # print STDERR "-",$KEYS{$type}, "-\n";
@@ -199,51 +167,27 @@ sub rconfreadfile {
 
         }
         
-	if (/^ATTR\s+(..)\s+(\S+)  (\s+([^\s\#]+))? (\s+([^\s\#]+))?/x) { 
-#             |       |     ||     |   ||           |   ||           
-#             ATTR    tc    |tech-c|   |pn,ro       |   |nic
-#                     $1    $2     $3  $4           $5  $6
-#
+	if (/^ATTR\s+(..)\s+(\S+)\s+([^\s\#]+\s)?/) { 
 	   $ATTR{$1}=$1; $ATTR{$2}=$1; $ATTL{$1}=$2;
 	    
 	   $MAXATTRIBUTELENGTH=length($2) if (length($2)>$MAXATTRIBUTELENGTH);
 	    
-	   if ($4) {
-	      my($tag) = $1;
+	   if ($3) {
+	      local($tag)=$1;
+	       
+	      $POINTSTO{$tag}=$3;
+	      $POINTSTO{$tag}=~ s/\s+$//;
+	      $POINTSTO{$tag}=~ s/\,/ /g;
 	       
-	      $POINTSTO{$tag} = $4;
-	      $POINTSTO{$tag} =~ s/\s+$//;
-	      $POINTSTO{$tag} =~ s/\,/ /g;
 	   }
-	   if ($6) {
-	       my($tag) = $1;
 	    
-	       if ($6 eq 'nic') {
-		   $POINTSTONIC{$tag} = 1;
-	       }
-	       else {
-		   $POINTSTOMT{$tag} = 1;
-	       }
-	   }
-
 	   next;
 	   
 	}
 	
-	# the following 3 options allow a LIST of IP's 
-	# to be specified on a line
 	
-	if (/^GETUPDATESFROM\s+(.*)/) { 
-	    push(@GETUPDATESFROM, split(/\s+/, $1)); next; 
-	}
-	if (/^DENYWHOISACCESS\s+(.*)/) { 
-	    push(@DENYWHOISACCESS, split(/\s+/, $1)); next;
-	}
-	if (/^WHOISUPDFROM\s+(.*)/) { 
-	    push(@WHOISUPDFROM, split(/\s+/, $1)); next; 
-	}
-	if (/^BINDADDR\s+(\d+\.\d+\.\d+\.\d+)\s*$/) { $BINDADDR = $1; next; }
-	if (/^BINDPORT\s+(\d+)\s*$/) { $BINDPORT = $1; next; }
+	if (/^GETUPDATESFROM\s+(\S.*\S)$/) { push(@GETUPDATESFROM,split(/\s+/,$1)); next; }
+	
 	if (/^MAILTXT\s+(.*)/) { $MAILTXT.=$1."\n"; next;}
 	if (/^ACKSIG\s+(.*)/) { $ACKSIG=$ACKSIG.$1."\n"; next;}
 	if (/^RIGHTS\s+(.*)/) { $RIGHTS.=$1."\n"; next; }
@@ -268,42 +212,24 @@ sub rconfreadfile {
 	if (/^SUCCESSTXT\s+(.*)/) { $SUCCESSTXT.=$1."\n"; next;}
 	if (/^FAILURETXT\s+(.*)/) { $FAILURETXT.=$1."\n"; next;}
 	if (/^HELPHEADER\s+(.*)/) { $HELPHEADER.=$1."\n"; next;}
+		
+	if (/^WHOISUPDFROM\s+(\S.*\S)$/) { push(@WHOISUPDFROM,split(/\s+/,$1)); next; }
 	
-	if (/^ATTA\s+(..)\s+(\S*)/)  { $ATTR{$2}=$1; next;}
-	if (/^REFERRALTXT\s+(.*)/)   { $REFERRALTXT.=$1."\n"; next;}
-	if (/^DENYACCESSTXT\s+(.*)/) { $DENYACCESSTXT.=$1."\n"; next;}
-	if (/^REFERRALERRORTXT\s+(.*)/) { $REFERRALERRORTXT.=$1."\n"; next;}
-	if (/^REFERRALLOOPERRORTXT\s+(.*)/) 
-	    { $REFERRALLOOPERRORTXT.=$1."\n"; next;}
-	if (/^REFERRALTIMEOUTTXT\s+(.*)/) 
-	    { $REFERRALTIMEOUTTXT.=$1."\n"; next;}
-	if (/^REFERRALTRUNCTXT\s+(.*)/) 
-	    { $REFERRALTRUNCTXT.=$1."\n"; next;}
-	if (/^REFERRALENDTXT\s+(.*)/)
-	    { $REFERRALENDTXT.=$1."\n"; next;}
-	if (/^REFERRALTIMEOUT\s+(\d+)/) {$REFERRALTIMEOUT = $1; next}
-	if (/^REFERRALMAXLINES\s+(\d+)/) {$REFERRALMAXLINES = $1; next}
-
+	if (/^ATTA\s+(..)\s+(\S*)/) { $ATTR{$2}=$1; next;}
 	
 	#
 	# we substract 10 to compensate for the extra bytes
 	# needed at the end of key, value and additional value
 	# plus comma and some bytes more to stay at the safe site ;-)
+	
 	if (/^OVERFLOWSIZE\s+(\d+)/) { $OVERFLOWSIZE=$1-10; next; }
 
 	if (/^DBCACHESIZE\s+(\d+)/) { $DBCACHESIZE=$1; next; }
-	if (/^MAXLISTLENGTH\s+(\d+)/) { $MAXLISTLENGTH=$1; next; }
-	if (/^MAXSTRINGCOMPONENTS\s+(\d+)/) { $MAXSTRINGCOMPONENTS=$1; next; }
 	
 	if (/^TESTMODE\s+(\d+)/) {$TESTMODE=$1; next;}
 	if (/^KEEPOPEN\s+(\d+)/) {$KEEPOPEN=$1; next;}
 	if (/^NROFNAMES\s+(\d+)/) {$NROFNAMES=$1; next;}
 	if (/^OVERRIDECRYPTEDPW\s+(\S+)/) { $OVERRIDECRYPTEDPW=$1; next; }
-
-	if (/^DUPLICATEPERSONCHECK\s+(\S+)/) { 
-	    $DUPLICATEPERSONCHECK=$1;
-	    next;
-	}
 	
 	# should check value - NOTIFY or ACK
 	if (/^SUPPRESSMESS\s+(\S+)/) { $SUPPRESSMESS = $1; next; }
@@ -315,10 +241,6 @@ sub rconfreadfile {
 	
 	if (/^MAILCMD\s+(.*)/) { $MAILCMD=$1; next;}
 
-        if (/^PGPV\s+(.*)/) { $PGPV=$1; next;}
-        if (/^PGPK\s+(.*)/) { $PGPK=$1; next;}
-	if (/^PGPPATH\s+(.*)/) { $PGPPATH=$1; next;}
-
 	if (/^CANUPD\s+(.+)$/) {
 	   foreach (split(/ /, $1)) {
 	      $CANUPD{$_}=1 if ($_);
@@ -326,52 +248,6 @@ sub rconfreadfile {
 	   next;
 	}
 
-        if (/^ALLOCMNT\s+(.+)$/) {
-	   foreach (split(/\s+/, $1)) {
-	      $ALLOCMNT{$_}=1;
-	   }
-    	   next;
-        }
-
-	# CROSSNOTIFYSOURCES <source> <list of sources to search for conflicts>
-	# $::CROSSNOTIFYSOURCES - hash indexed on source name
-	#                      - values are refs to arrays of source names
-	if (/^CROSSNOTIFYSOURCES\s+/) {
-	  use strict;
-
-	  my(@sources) = split;
-	  next unless @sources > 2;
-
-	  shift @sources;   # skip keyword
-
-	  my($key) = shift @sources;
-	  $::CROSSNOTIFYSOURCES{$key} = \@sources;
-	  next;
-	}
-
-	# '\s+' will greedily match all whitespace so we want everything
-	# after the match - ie $'
-	if (/^CN_SUBJECT_ADD\s+/) { $::CN_ADD{SUBJECT} .= $'; next; }
-	if (/^CN_EXPLAIN_ADD\s+/) { $::CN_ADD{EXPLAIN} .= $'; next; }
-	if (/^CN_OVERLAP_ADD\s+/) { $::CN_ADD{OVERLAP} .= $'; next; }
-	if (/^CN_SUBJECT_DEL\s+/) { $::CN_DEL{SUBJECT} .= $'; next; }
-	if (/^CN_EXPLAIN_DEL\s+/) { $::CN_DEL{EXPLAIN} .= $'; next; }
-	if (/^CN_OVERLAP_DEL\s+/) { $::CN_DEL{OVERLAP} .= $'; next; }
-
-	if (/^CNO_SUBJECT_ADD\s+/) { $::CNO_ADD{SUBJECT} .= $'; next; }
-	if (/^CNO_EXPLAIN_ADD\s+/) { $::CNO_ADD{EXPLAIN} .= $'; next; }
-	if (/^CNO_OVERLAP_ADD\s+/) { $::CNO_ADD{OVERLAP} .= $'; next; }
-	if (/^CNO_SUBJECT_DEL\s+/) { $::CNO_DEL{SUBJECT} .= $'; next; }
-	if (/^CNO_EXPLAIN_DEL\s+/) { $::CNO_DEL{EXPLAIN} .= $'; next; }
-	if (/^CNO_OVERLAP_DEL\s+/) { $::CNO_DEL{OVERLAP} .= $'; next; }
-
-#	if (/^CNO_SUBJECT_ADD\s+(\S+)/) { $::CNO_SUBJECT_ADD .= $1; next; }
-#	if (/^CNO_SUBJECT_DEL\s+(\S+)/) { $::CNO_SUBJECT_DEL .= $1; next; }
-#	if (/^CNO_EXPLAIN_ADD\s+(\S+)/) { $::CNO_EXPLAIN_ADD .= $1; next; }
-#	if (/^CNO_EXPLAIN_DEL\s+(\S+)/) { $::CNO_EXPLAIN_DEL .= $1; next; }
-#	if (/^CNO_OVERLAP_ADD\s+(\S+)/) { $::CNO_OVERLAP_ADD .= $1; next; }
-#	if (/^CNO_OVERLAP_DEL\s+(\S+)/) { $::CNO_OVERLAP_DEL .= $1; next; }
-
 	if (/^DEFLOOK\s+(\S.*)/) { $DEFLOOK.=" ".$1; $DEFLOOK=~ s/\s+/ /g; $DEFLOOK=~ s/^ //; $DEFLOOK=~ s/ $//; next; }
 	if (/^ALLLOOK\s+(\S.*)/) { print STDERR "ALLLOOK variable is now auto-generated from the DBFILE variable"; next }
 	
@@ -429,7 +305,6 @@ sub rconfreadfile {
 	if (/^OBJDESC\s+(\S+)/) {$OBJDESC=$1; next }
 
 	if (/^QRYLOG\s+(\S+)/) { $LOGFILE{"QRYLOG"}=$1; next; }
-	if (/^QRY2LOG\s+(\S+)/) { $LOGFILE{"QRY2LOG"}=$1; next; }
 	if (/^ERRLOG\s+(\S+)/) { $LOGFILE{"ERRLOG"}=$1; next; }
 	if (/^AUDITLOG\s+(\S+)/) { $LOGFILE{"AUDITLOG"}=$1; next; }
 	if (/^UPDLOG\s+(\S+)/) { $LOGFILE{"UPDLOG"}=$1; next; }
@@ -469,35 +344,24 @@ sub rconfreadfile {
 	
     }
     close(CONF);
-
-
-}
-
-
-sub rconfprocess{
     
     local($j,@tmp);
     local(%ALLPOINTSTO)=();
-    local(%ALLPOINTSTONICATTR)=();
-    local(%ALLPOINTSTOMTATTR)=();
     local(%ALLPOINTSTOATTR)=();
     local(%ALLKEYS)=();
     local(%OBJPOINTSTOTMP);
     local(%OBJPOINTSTOATTRTMP);
-    local(%OBJPOINTSTONICATTRTMP);
-    local(%OBJPOINTSTOMTATTRTMP);
     local(%OBJKEYSTMP);
-    local(%ALLOBJORDEREDTMP);
     
     foreach $i (keys %OBJATSQ) {
      
-#       $ALLNICPOINTSTO.=" ".$i if ($POINTSTO{$i}=~ /\b(ro|pn)\b/);
-#       $ALLMTPOINTSTO.=" ".$i if ($POINTSTO{$i}=~ /\b(mt)\b/);
+       $ALLNICPOINTSTO.=" ".$i if ($POINTSTO{$i}=~ /(^| )(ro|pn)( |$)/);
+       $ALLMTPOINTSTO.=" ".$i if ($POINTSTO{$i}=~ /(^| )mt( |$)/);
        
        #
        # NIC handle DBS'es
        
-       push(@NICHANDLEDBS, $i) if ($OBJATSQ{$i}=~ /\b(nh)\b/);  
+       push(@NICHANDLEDBS, $i) if ($OBJATSQ{$i}=~ /(^| )nh( |$)/);  
        
        #
        # CLASSLESS DBS'es
@@ -513,34 +377,30 @@ sub rconfprocess{
        
        %OBJPOINTSTOTMP=();
        %OBJPOINTSTOATTRTMP=();
-       %OBJPOINTSTONICATTRTMP=();
-       %OBJPOINTSTOMTATTRTMP=();				   
        %OBJKEYSTMP=();
 
        @tmp=grep(!$OBJATSQ{$_}, split(/ /, $KEYS{$i}));
+       # @tmp=split(/ /, $KEYS{$i});
        
        if (@tmp) {
           @KEYS{@tmp}=(1) x @tmp;
           @OBJKEYSTMP{@tmp}=(1) x @tmp;
           @ALLKEYS{@tmp}=(1) x @tmp;
        }
-
        if ($KEYS{$i}) {
           $OBJKEYSTMP{$i}=1;
           $ALLKEYS{$i}=1;
        }
        
+       # print STDERR "tmp: ", join(" ", @tmp)," tmp keys ($i): ",join(" ", @OBJKEYSTMP{@tmp}), "keys: ", join(" ", @KEYS{@tmp}), "\n";
+       
        foreach $j (split(/ /, $OBJATSQ{$i})) {
           
           next if (!$POINTSTO{$j});
           
           $OBJKEYSTMP{$j}=1;
           $ALLPOINTSTOATTR{$j}=1;
-          $ALLPOINTSTONICATTR{$j}=1 if ($POINTSTONIC{$j});
-          $ALLPOINTSTOMTATTR{$j}=1 if ($POINTSTOMT{$j});
           $OBJPOINTSTOATTRTMP{$j}=1;
-	  $OBJPOINTSTONICATTRTMP{$j} = 1 if ($POINTSTONIC{$j});
-	  $OBJPOINTSTOMTATTRTMP{$j} = 1 if ($POINTSTOMT{$j});
            
           @tmp=split(/ /, $POINTSTO{$j});
              
@@ -551,37 +411,19 @@ sub rconfprocess{
              
        $OBJPOINTSTO{$i}=join(" ", keys %OBJPOINTSTOTMP);
        $OBJPOINTSTOATTR{$i}=join(" ", keys %OBJPOINTSTOATTRTMP);
-       $OBJPOINTSTONICATTR{$i}=join(" ", keys %OBJPOINTSTONICATTRTMP);
-       $OBJPOINTSTOMTATTR{$i}=join(" ", keys %OBJPOINTSTOMTATTRTMP);
-       $OBJPOINTSTONICMTATTR{$i}=$OBJPOINTSTONICATTR{$i}." ".$OBJPOINTSTOMTATTR{$i};
        $OBJKEYS{$i}=join(" ", keys %OBJKEYSTMP);
        
        # print STDERR "keys ($i): $OBJKEYS{$i}\npoints to ($i): $OBJPOINTSTO{$i}\n";
        
     }
     
-#    $ALLNICPOINTSTO=~ s/^ //;
-#    $ALLMTPOINTSTO=~ s/^ //;
- 
-    $ALLPOINTSTONIC   = 'pn ro';
-    $ALLPOINTSTOMT    = 'mt';
-    $ALLPOINTSTONICMT = $ALLPOINTSTONIC . " " . $ALLPOINTSTOMT;
-   
-    $ALLPOINTSTO = join(" ", keys %ALLPOINTSTO);
-    $ALLPOINTSTOATTR = join(" ", keys %ALLPOINTSTOATTR);
-    $ALLPOINTSTONICATTR = join(" ", keys %ALLPOINTSTONICATTR);
-    $ALLPOINTSTOMTATTR = join(" ", keys %ALLPOINTSTOMTATTR);
-    $ALLPOINTSTONICMTATTR = $ALLPOINTSTONICATTR . " " . $ALLPOINTSTOMTATTR;
+    $ALLNICPOINTSTO=~ s/^ //;
+    $ALLMTPOINTSTO=~ s/^ //;
+    
+    $ALLPOINTSTO=join(" ", keys %ALLPOINTSTO);
+    $ALLPOINTSTOATTR=join(" ", keys %ALLPOINTSTOATTR);
     $ALLKEYS=join(" ", keys %ALLOBJKEYS);
     
-    %ALLOBJORDEREDTMP = %OBJATSQ;
-    foreach (split(/ /, $ALLPOINTSTONICMT)) {
-	delete($ALLOBJORDEREDTMP{$_});
-    }
-    @ALLOBJORDERED = sort keys %ALLOBJORDEREDTMP;
-    push(@ALLOBJORDERED, split(/ /, $ALLPOINTSTONICMT));
-    $ALLOBJORDERED = join(" ", @ALLOBJORDERED);
-
     if (%CLASSLESSDBS) {
        
        local($db);
@@ -647,10 +489,10 @@ sub rconfprocess{
     # check mandatory files exist
     {
       (-f $AUTODBMHELP) ||
-	&fatalerror("file (option AUTODBMHELP): [$AUTODBMHELP] doesn't exist");
+	&fatalerror("file (option HELP): $HELP doesn't exist");
 
       (-f $WHOISHELP) ||
-	&fatalerror("file (option WHOISHELP): [$WHOISHELP] doesn't exist");
+	&fatalerror("file (option WHOISHELP): $WHOISHELP doesn't exist");
     }
 
 
@@ -670,17 +512,6 @@ sub rconfprocess{
       }
     }
 
-    # check if we have PGP
-    $have_pgp = defined($PGPK) && defined($PGPV);
-
-    if ($have_pgp) { 
-      fatalerror("PGPK binary $PGPK is not executable") unless -x $PGPK;
-      fatalerror("PGPV binary $PGPV is not executable") unless -x $PGPV;
-      fatalerror("PGPPATH directory $PGPPATH does not exist") 
-	  unless -d $PGPPATH;
-      $ENV{"PGPPATH"} = $PGPPATH;
-    }
-
     &ReplaceGlobalVars(*RIGHTS);
 
     # 
