@@ -1,6 +1,6 @@
 #       serial - serialize updates & support routines
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,15 +19,14 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: serial.pl,v 2.4 1998/12/09 14:39:24 roman Exp $
+# $Id: serial.pl,v 2.2 1997/10/02 15:26:05 chris Exp $
 #
 #	$RCSfile: serial.pl,v $
-#	$Revision: 2.4 $
-#	$Author: roman $
-#	$Date: 1998/12/09 14:39:24 $
+#	$Revision: 2.2 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:26:05 $
 
 require "defines.pl";
-require "dpr.pl";
 
 # open a serial file
   
@@ -107,7 +106,7 @@ sub getcurrentserial {
 
    local($serialfile, $serial)=&openandreadserial($source.$CURRENTEXTENSION, "getcurrentserial");
    
-#   &dpr("CurrentSerial: *$serial*\n");
+   print STDERR "CurrentSerial: *$serial*\n" if $opt_V;
    
    close($serialfile) || &fatalerror("getcurrentserial - cannot close/unlock serial file");
     
@@ -119,7 +118,7 @@ sub getoldestserial {
 
    local($serialfile, $serial)=&openandreadserial($source.$OLDESTEXTENSION, "getoldestserial");
    
-#   &dpr("OldestSerial: *$serial*\n");
+   print STDERR "OldestSerial: *$serial*\n" if $opt_V;
    
    close($serialfile) || &fatalerror("getoldestserial - cannot close/unlock serial file");
    
