@@ -1,6 +1,6 @@
 # syncdb.pl
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: syncdb.pl,v 2.16 1999/02/02 11:37:53 marek Exp $
+# $Id: syncdb.pl,v 2.12 1997/10/22 09:07:31 chris Exp $
 #
 #	$RCSfile: syncdb.pl,v $
-#	$Revision: 2.16 $
-#	$Author: marek $
-#	$Date: 1999/02/02 11:37:53 $
+#	$Revision: 2.12 $
+#	$Author: chris $
+#	$Date: 1997/10/22 09:07:31 $
 
 # This is a client that will update objects read from a file directly
 # in the database, without interference of updated.
@@ -46,14 +46,13 @@ require "enread.pl";
 require "enwrite.pl";
 require "misc.pl";
 require "rconf.pl";
-require "dpr.pl";
 
 require "syslog.pl";     # nothing to do with the system 'syslog.pl'
 require "whoisqry.pl";
 
 ## parse command line
 
-Getopt::Std::getopts('h:p:s:u:p:Vb');
+Getopt::Std::getopts('h:s:u:V');
 
 $::WHOIS_HOST = $::RIPEConfig{WHOISHOST};
 $::WHOIS_HOST = $opt_h if $opt_h;
@@ -61,26 +60,21 @@ $::WHOIS_HOST = $opt_h if $opt_h;
 $::WHOIS_PORT = '';
 $::WHOIS_PORT = $opt_p if $opt_p;
 
-$Main::is_update=1;
-
 # check command line and maybe print usage 
 if ((!$opt_s) || (($opt_u) && ($opt_u!~ /^\d+\:\d+$/))) {
 
   print <<"EOF";
     
-Usage: $PROGRAMNAME [ -h hostname ] [ -p portno ] -s source [ -u period:delay ]
+Usage: $PROGRAMNAME [ -h hostname ] -s source [ -u period:delay ]
    
 Where:
 
 -h hostname      - hostname of server that provides updates.
                    Default - $::RIPEConfig{WHOISHOST}
--p portno        - port number of server that provides updates.
-                   Default - look up service "whois" in /etc/services
 -s source        - which source to query for
 -u period:delay  - the program will run for 'period' seconds and
                    will do a query every 'delay' seconds
--V               - verbose output
--b               - prints a lot of useless debugging information
+
 EOF
 
   exit 1;
@@ -112,7 +106,7 @@ EOF
 # run on low priority, whois server queries have an
 # higher priority
 
-&lower_priority();
+lower_priority;
 
 %entry=();
 
@@ -169,7 +163,7 @@ sub exitsyncdbase {
 sub skiperrorserial {
    local(*entry,$action,$source,$msg)=@_;
    
-   $entry{"pn"}="problem found" if (!&entype(%entry));
+   $entry{"pn"}="problem found" if (!&entype(*entry));
    $entry{"so"}=$source if (!$entry{"so"});
    
    &adderror(*entry,$msg);
@@ -188,7 +182,7 @@ sub doaction {
 
     local(*entry,$type,$action,$source,$serial) = @_;
     
-#    &dpr("doaction($action,$serial) called\n");
+    print STDERR "syncdbase - doaction($action,$serial) called\n" if $opt_V;
     
     local($returncode)=0;
     
@@ -198,20 +192,20 @@ sub doaction {
     local($mirrordb)='mirrordb';
     local(%mirrordb,@mirrordb);
     
-#    &dpr("doaction opening database\n");
+    print STDERR "syncdbase - doaction opening database\n" if $opt_V;
 
-#    local($type)=&entype(%entry);
+#    local($type)=&entype(*entry);
 
     if (&dbopen(*mirrordb, *entry, 1)) {
        # Open classless database
 
-#       &dpr("doaction opening classless db\n");
+       print STDERR "syncdbase - doaction opening classless db\n" if $opt_V;
        &dbclopen(*entry,1) if ($CLASSLESSDBS{$type});
 
        # Looks like we have some locking problem, so let's
        # lock the thing before we do anything else ...
 
-#       &dpr("doaction locking databases\n");
+       print STDERR "syncdbase - doaction locking databases\n" if $opt_V;
 		
        # do we delete or not ?
 
@@ -224,13 +218,13 @@ sub doaction {
        
           if ($action=~ /^$DELETEACTION$/i) {
 
-#             &dpr("doaction deleting entry ($entry{$type})\n");
+             print STDERR "syncdbase - doaction deleting entry ($entry{$type})\n" if $opt_V;
              $dbstat = &dbdel(*mirrordb, *entry, $type, $DELETEOPTION | $NOCHECKSOPTION);
 
           }
           elsif ($action=~ /^$ADDACTION$/i) {
           
-#             &dpr("doaction adding entry ($entry{$type})\n");
+             print STDERR "syncdbase - doaction adding entry ($entry{$type})\n" if $opt_V;
              $dbstat = &dbadd(*mirrordb, *entry, $type, 0);
           
           }
@@ -240,18 +234,18 @@ sub doaction {
        #
        # noop, just print stat if verbose but always print errors!!!
 
-#       &dpr("doaction checking stat\n");
+       print STDERR "syncdbase - doaction checking stat\n" if $opt_V;
 
        if ($dbstat == $E_NOOP) {
           print STDERR "ERROR, incomingserial ($action: $entry{$type}): ", $LOGFILE{"SERIALINCOMINGDIR"}, $serial, " [NOOP]\n\n";
-          &skiperrorserial(*entry,$action,$source,eval $MESSAGE[$dbstat]);
+          &skiperrorserial(*entry,$action,$source,$MESSAGE[$dbstat]);
        }
        elsif ($dbstat!=$OK) {
-          print STDERR "ERROR, incomingserial ($action: $entry{$type}): ", $LOGFILE{"SERIALINCOMINGDIR"}, $serial, " ", eval $MESSAGE[$dbstat], "\n\n";
-          &skiperrorserial(*entry,$action,$source,eval $MESSAGE[$dbstat]);
+          print STDERR "ERROR, incomingserial ($action: $entry{$type}): ", $LOGFILE{"SERIALINCOMINGDIR"}, $serial, " ", $MESSAGE[$dbstat], "\n\n";
+          &skiperrorserial(*entry,$action,$source,$MESSAGE[$dbstat]);
        }
-       else {
-#          &dpr("OK, ($action: $entry{$type}) serial: $serial\n");
+       elsif ($opt_V) {
+          print STDERR "OK, ($action: $entry{$type}) serial: $serial\n";
        }
 
        &dbclose(*mirrordb);
@@ -280,7 +274,7 @@ sub UpdateVersionOne {
    
    my $basename = $LOGFILE{"SERIALINCOMINGDIR"}.$source;
    
-#   &dpr("basename: $basename source: $source first: $first last: $last\n");
+   print STDERR "basename: $basename source: $source first: $first last: $last\n" if $opt_V;
       
    $i=$first;
    $line=<$input>;
@@ -296,7 +290,7 @@ sub UpdateVersionOne {
           ($line!~ /^\s*$/) &&
           ($line!~ /^\%END/)) {
    
-#      &dpr("update: $basename.$i\n");
+      print STDERR "update: $basename.$i\n" if $opt_V;
       
       if ($line=~ /^$ADDACTION$/i) {
          $action=$ADDACTION;
@@ -328,6 +322,8 @@ sub UpdateVersionOne {
 	close(OUTP);
       }
 
+      print STDERR "action: $action\n" if $opt_V;  
+      
       &doaction(*oldentry,$oldtype,$oldaction,$source,$oldi) if ($i!=$first);
    
       %oldentry=%entry;
@@ -347,6 +343,7 @@ sub UpdateVersionOne {
 
    if ($line=~ /^\s*$/) {
       $line=<TMPFILE>;
+      print STDERR "read extra line: ", $line if $opt_V;
    }
 
    if ($STOPUPDATING) {
@@ -477,8 +474,11 @@ if ($opt_u) {
      srand;
      my $random = abs rand(60);
 
+     print STDERR "Sleeping for $random seconds..." if $opt_V;
+
      sleep $random;
 
+     print STDERR "done\n" if $opt_V;
    }
    
 }
@@ -538,6 +538,7 @@ QUERY: while ((!$TIMEOUT) && (!$STOPUPDATING)) {
    
 LINE:   
    while (($line=<TMPFILE>) && ($line!~ /^\%START/)) { 
+      print STDERR "skip:", $line if $opt_V;
    
       ## If there were no updates available we get '% Warning (1)
       ## Just close the TMPFILE and do the next query
@@ -545,7 +546,6 @@ LINE:
 
       if ($line =~ /\s*%\s+Warning\s+\(1\)/) {
 	close TMPFILE;
-	&exitsyncdbase("No more updates available") if (!$period);
 	next QUERY;
       }
 
@@ -590,11 +590,13 @@ LINE:
    }
    else {
    
+      print STDERR "last:", $line if $opt_V;
+
       #
       # call the right updating procedure
    
       if ($line=~ /^\%START\s+Version:\s*(\d+)\s+/) {
-
+         print STDERR "found: ", $line if $opt_V;
          $version=$1;
    
          if ($version==1) {
@@ -631,6 +633,7 @@ LINE:
     while (!$TIMEOUT && $oldmtime==$mtime) {
       sleep $delay;
       $mtime=(stat($SYNCFASTMODE))[9];
+      print STDERR "old: $oldmtime mtime: $mtime\n" if ($opt_V);
     }
    
   }
