@@ -1,6 +1,6 @@
 #	syslog - simplified syslog "type" routine.
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: syslog.pl,v 2.5 1999/05/28 16:19:49 roman Exp $
+# $Id: syslog.pl,v 2.1 1997/10/02 15:26:10 chris Exp $
 #
 #	$RCSfile: syslog.pl,v $
-#	$Revision: 2.5 $
-#	$Author: roman $
-#	$Date: 1999/05/28 16:19:49 $
+#	$Revision: 2.1 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:26:10 $
 #
 #	It allows you to write to various logfiles defined in general config
 #	
@@ -40,7 +40,7 @@ sub fatalerror {
 
    # log in as many places as possible...
 
-   local($error)="Fatal error: ".join("", @_)." PID: $$\n";
+   local($error)="Fatal error: ".join("", @_)."\n";
 
    if (&syslog("ERRLOG", $error)) {
       
@@ -54,27 +54,23 @@ sub fatalerror {
    
    }
    
-   exit 100;
+   exit 1;
 
 }
 
 sub syslog {
-    local($log, $string, $nostamp) = @_;
-    local($date);
+    local($log, $string) = @_;
 
-    if ($nostamp) {
-	$date = "";
-    }
-    else {
-	# Get the time
-	local($s, $m, $h, $md, $mo, $y, $wd, $yd, $is) = localtime(time);
-	local($thismonth) = 
-	    (Jan,Feb,Mar,Apr,May,Jun,Jul,Aug,Sep,Oct,Nov,Dec)[$mo];
-	$s = "0".$s unless $s > 9;
-	$m = "0".$m unless $m > 9;
-	$h = "0".$h unless $h > 9;
-	$date = sprintf("%3s %2d %2s:%2s:%2s", $thismonth,$md,$h,$m,$s);
-    }
+    # Get the time
+
+    local($s, $m, $h, $md, $mo, $y, $wd, $yd, $is) = localtime(time);
+    local($thismonth) = (Jan,Feb,Mar,Apr,May,Jun,Jul,Aug,Sep,Oct,Nov,Dec)[$mo];
+
+    $s = "0".$s unless $s > 9;
+    $m = "0".$m unless $m > 9;
+    $h = "0".$h unless $h > 9;
+
+    local($date) = sprintf("%3s %2d %2s:%2s:%2s", $thismonth,$md,$h,$m,$s);
 
     #
     # Now we got a date let's open the logfile
