@@ -1,6 +1,6 @@
 # The new template.pl file
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,7 +19,7 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: template.pl,v 2.6 1998/12/09 14:39:28 roman Exp $
+# $Id: template.pl,v 2.4 1997/10/02 12:33:33 chris Exp $
 #
 # new_template.pl
 #
@@ -134,17 +134,6 @@ sub Template	{
  	next if (grep(/\b$attribute\b/, $OBS{$type}) );
 
 
-# Special for objects with generated attributes
-	if ( grep(/\b$attribute\b/, $GEN{$type}) ) {
-	 printf $output "%-12s %-12s %-12s %-25s\n",
-	 $ATTL{$attribute}.":",
-	 "[generated]",
-	 grep(/\b$attribute\b/, $OBJMULT{$type}) ? "[multiple]"  : "[single]",  
-	 grep(/\b$attribute\b/, keys(%indexes) ) ? $indexes{$attribute} : "[ ]";
-#If the object has an attr of type GEN skip the following block
-	 next;
-	}
-
 	printf $output "%-12s %-12s %-12s %-25s\n",
 	$ATTL{$attribute}.":",
 	grep(/\b$attribute\b/, $OBJMAND{$type}) ? "[mandatory]" : "[optional]",
