@@ -1,6 +1,6 @@
 # udpatecheck.pl
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: updatecheck.pl,v 2.4 1999/05/28 16:19:49 roman Exp $
+# $Id: updatecheck.pl,v 2.1 1997/10/02 15:26:12 chris Exp $
 #
 #	$RCSfile: updatecheck.pl,v $
-#	$Revision: 2.4 $
-#	$Author: roman $
-#	$Date: 1999/05/28 16:19:49 $
+#	$Revision: 2.1 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:26:12 $
 
 require "defines.pl";
 require "adderror.pl";
@@ -114,7 +114,7 @@ sub updatecheck {
     local(*db, *oldobject, *newobject, $type, $options)=@_;
 
     return $O_OK if ($options & $NOCHECKSOPTION);
-#    &dpr("override option: ", ($options & $OVERRIDEOPTION), "\n");
+
     local($returncode)=$O_OK;
     
     #
@@ -122,9 +122,8 @@ sub updatecheck {
     # a maintainer but don't have one in the old object
                 
     return $E_NOAUTOUPDATE if ((!($options & $OVERRIDEOPTION)) && 
-                               ($OBJMAND{$type}=~ /\bmb\b/) && 
-                               (!defined($oldobject{"mb"})) &&
-			       (!($options & $NEWOPTION)));
+                               ($OBJMAND{$type}=~ /^(^| )mb( |$)/) && 
+                               (!defined($oldobject{"mb"})));
 
     #
     # If this is a maintainer object, bounce it of to the human mailbox
@@ -206,22 +205,9 @@ sub updatecheck {
     # And now the hierarchical authorization
     # only for creation right now...
        
-    $hierstat = 
-	&HierarchicalAuthorization(*db, *oldobject,*newobject, $type, $options);
-
-    if ($hierstat == $O_OK) {
-	&NotifyMaintainers(*oldobject, *newobject, "");
-	return $returncode;
-    }
-    else {
-	return $E_HIER_AUTHFAIL;
-    }
-
-#    return $E_HIER_AUTHFAIL 
-#    if ($O_OK != &HierarchicalAuthorization
-#	(*db, *oldobject, *newobject, $type, $options));
+    return $E_HIER_AUTHFAIL if ($O_OK!=&HierarchicalAuthorization(*db, *oldobject, *newobject, $type, $options));
     
-#    return $returncode;
+    return $returncode;
     
 }
 
