@@ -1,6 +1,6 @@
 # whois.pl - simple whois client
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,24 +19,24 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: whois.pl,v 2.7 1998/12/09 14:39:28 roman Exp $
+# $Id: whois.pl,v 2.3 1997/10/02 15:26:12 chris Exp $
 #
 #	$RCSfile: whois.pl,v $
-#	$Revision: 2.7 $
-#	$Author: roman $
-#	$Date: 1998/12/09 14:39:28 $
+#	$Revision: 2.3 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:26:12 $
 
 # This is a very simple whois client, but it knows the new server arguments
 
 require "getopts.pl";
 
-&Getopts('aFg:h:i:LmMp:rRs:St:v:T:');
+&Getopts('aFg:h:i:LmMp:rs:St:v:T:');
 
 if ((!@ARGV) && (!$opt_t) && (!$opt_g) && (!$opt_v) && (!(($opt_g) && ($opt_t)))) {
     
     print <<"EOF";
 
-Usage: whois [-acFLmMrSv] [-h hostname] [-s sources] [-T types] [-i attr] keys
+Usage: whois [-aFLmMrSv] [-h hostname] [-s sources] [-T types] [-i attr] keys
        whois -t type 	whois -v type
 
 Where:
@@ -50,7 +50,6 @@ Where:
 -M                         find all More specific matches
 -p port                    port to connect to
 -r                         turn off recursive lookups
--R                         do not trigger referral mechanism
 -s source[[,source] ... ]  search databases with source 'source'
 -S                         tell server to leave out 'syntactic sugar'
 -t type                    requests template for object of type 'type'
@@ -94,7 +93,6 @@ $query.="-L "            if ($opt_L);
 $query.="-m "            if ($opt_m);
 $query.="-M "            if ($opt_M);
 $query.="-r "            if ($opt_r);
-$query.="-R "            if ($opt_R);
 $query.="-S "            if ($opt_S);
 $query.="-s ".$opt_s." " if ($opt_s);
 $query.="-t ".$opt_t." " if ($opt_t);
@@ -108,8 +106,8 @@ $query.="-T ".$opt_T." " if ($opt_T);
 # RIPE whois server
 
 if (($opt_h=~ /(ripe\.net|ra\.net|apnic\.net|mci\.net|isi\.edu|garr\.it|ans\.net)$/i) ||
-    $opt_a || $opt_g || $opt_F || $opt_i || $opt_m || $opt_M || $opt_R ||
-    $opt_L || $opt_r || $opt_s || $opt_S || $opt_t || $opt_v || $opt_T) {
+    $opt_a || $opt_g || $opt_F || $opt_i || $opt_m || $opt_M || $opt_L ||
+    $opt_r || $opt_s || $opt_S || $opt_t || $opt_v || $opt_T) {
     
    $query.="-Vwp2.0 ";
 
