@@ -1,6 +1,6 @@
 # whoisquery.pl
 #
-# Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998, 1999 by RIPE NCC
+# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
 #
 # All Rights Reserved
 #
@@ -19,12 +19,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: whoisqry.pl,v 2.4 1998/12/09 14:39:31 roman Exp $
+# $Id: whoisqry.pl,v 2.2 1997/10/02 15:26:13 chris Exp $
 #
 #	$RCSfile: whoisqry.pl,v $
-#	$Revision: 2.4 $
-#	$Author: roman $
-#	$Date: 1998/12/09 14:39:31 $
+#	$Revision: 2.2 $
+#	$Author: chris $
+#	$Date: 1997/10/02 15:26:13 $
 
 # This is a very simple whois client module
 
@@ -61,10 +61,6 @@ sub initwhoisqry {
     else {
        $address=(gethostbyname($host))[4];
     }
-
-    unless ($address) {
-       return "Connect to host: $host port: $port failed: host unknown";
-    }
     
     # find valid port and protocol number for whois service
     
@@ -94,7 +90,7 @@ sub initwhoisqry {
     }
     else {
     
-       return "Connect to host: $host port: $port failed: $!";
+       return ("Connect to host: $host port: $port failed");
 
     }
     
